/* spice-display.c generated by valac 0.29.2.1-265d, the Vala compiler
 * generated from spice-display.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <spice-client.h>
#include <spice-widget.h>
#include <glib/gi18n-lib.h>
#include <config.h>
#include <gio/gio.h>
#include <libusb.h>
#include <libxml/uri.h>


#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
typedef struct _BoxesDisplayPrivate BoxesDisplayPrivate;

#define BOXES_TYPE_SPICE_DISPLAY (boxes_spice_display_get_type ())
#define BOXES_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay))
#define BOXES_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))
#define BOXES_IS_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_IS_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_SPICE_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))

typedef struct _BoxesSpiceDisplay BoxesSpiceDisplay;
typedef struct _BoxesSpiceDisplayClass BoxesSpiceDisplayClass;
typedef struct _BoxesSpiceDisplayPrivate BoxesSpiceDisplayPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))
#define __vala_SpiceUsbDevice_free0(var) ((var == NULL) ? NULL : (var = (_vala_SpiceUsbDevice_free (var), NULL)))
#define _g_ptr_array_unref0(var) ((var == NULL) ? NULL : (var = (g_ptr_array_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block65Data Block65Data;
typedef struct _Block66Data Block66Data;
typedef struct _Block67Data Block67Data;
typedef struct _Block68Data Block68Data;
typedef struct _Block69Data Block69Data;
typedef struct _Block70Data Block70Data;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _libusb_unref_device0(var) ((var == NULL) ? NULL : (var = (libusb_unref_device (var), NULL)))
#define _libusb_free_config_descriptor0(var) ((var == NULL) ? NULL : (var = (libusb_free_config_descriptor (var), NULL)))
#define _xmlFreeURI0(var) ((var == NULL) ? NULL : (var = (xmlFreeURI (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef gint (*BoxesDisplayOpenFDFunc) (void* user_data);
struct _BoxesDisplay {
	GObject parent_instance;
	BoxesDisplayPrivate * priv;
	gboolean connected;
	GHashTable* displays;
};

struct _BoxesDisplayClass {
	GObjectClass parent_class;
	GtkWidget* (*get_display) (BoxesDisplay* self, gint n);
	GdkPixbuf* (*get_pixbuf) (BoxesDisplay* self, gint n, GError** error);
	void (*set_enable_inputs) (BoxesDisplay* self, GtkWidget* widget, gboolean enable);
	void (*set_enable_audio) (BoxesDisplay* self, gboolean enable);
	gboolean (*should_keep_alive) (BoxesDisplay* self);
	void (*connect_it) (BoxesDisplay* self, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target, GError** error);
	void (*disconnect_it) (BoxesDisplay* self);
	void (*collect_logs) (BoxesDisplay* self, GString* builder);
	void (*send_keys) (BoxesDisplay* self, guint* keyvals, int keyvals_length1);
	GList* (*get_properties) (BoxesDisplay* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	const gchar* (*get_protocol) (BoxesDisplay* self);
	gchar* (*get_uri) (BoxesDisplay* self);
};

struct _BoxesSpiceDisplay {
	BoxesDisplay parent_instance;
	BoxesSpiceDisplayPrivate * priv;
};

struct _BoxesSpiceDisplayClass {
	BoxesDisplayClass parent_class;
};

struct _BoxesSpiceDisplayPrivate {
	BoxesMachine* machine;
	SpiceSession* session;
	SpiceGtkSession* gtk_session;
	SpiceAudio* audio;
	gulong channel_new_id;
	gulong channel_destroy_id;
	BoxesBoxConfigSyncProperty* display_sync_properties;
	gint display_sync_properties_length1;
	gint _display_sync_properties_size_;
	BoxesBoxConfigSyncProperty* gtk_session_sync_properties;
	gint gtk_session_sync_properties_length1;
	gint _gtk_session_sync_properties_size_;
	gboolean closed;
	SpiceMainChannel* main_channel;
	gulong main_event_id;
	gulong main_mouse_mode_id;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _Block65Data {
	int _ref_count_;
	BoxesSpiceDisplay* self;
	BoxesDisplayOpenFDFunc open_fd;
	gpointer open_fd_target;
};

struct _Block66Data {
	int _ref_count_;
	Block65Data * _data65_;
	SpiceChannel* channel;
};

struct _Block67Data {
	int _ref_count_;
	Block66Data * _data66_;
	SpiceDisplay* display;
};

struct _Block68Data {
	int _ref_count_;
	BoxesSpiceDisplay* self;
	SpiceUsbDeviceManager* manager;
	BoxesProperty* usb_property;
};

struct _Block69Data {
	int _ref_count_;
	GPtrArray* self;
	GCompareFunc compare_func;
};

struct _Block70Data {
	int _ref_count_;
	Block68Data * _data68_;
	SpiceUsbDevice* dev;
	GtkSwitch* dev_toggle;
};


static gpointer boxes_spice_display_parent_class = NULL;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_display_get_type (void) G_GNUC_CONST;
GType boxes_spice_display_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
#define BOXES_SPICE_DISPLAY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayPrivate))
enum  {
	BOXES_SPICE_DISPLAY_DUMMY_PROPERTY,
	BOXES_SPICE_DISPLAY_PROTOCOL,
	BOXES_SPICE_DISPLAY_URI,
	BOXES_SPICE_DISPLAY_CA_CERT
};
static void boxes_spice_display_main_cleanup (BoxesSpiceDisplay* self);
static void _vala_BoxesBoxConfigSyncProperty_array_free (BoxesBoxConfigSyncProperty* array, gint array_length);
static void boxes_spice_display_ui_state_changed (BoxesSpiceDisplay* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
GtkWidget* boxes_display_get_display (BoxesDisplay* self, gint n);
static gchar* boxes_spice_display_get_box_name (BoxesSpiceDisplay* self);
BoxesBoxConfig* boxes_display_get_config (BoxesDisplay* self);
BoxesSpiceDisplay* boxes_spice_display_new (BoxesMachine* machine, BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port, const gchar* host_subject);
BoxesSpiceDisplay* boxes_spice_display_construct (GType object_type, BoxesMachine* machine, BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port, const gchar* host_subject);
BoxesDisplay* boxes_display_construct (GType object_type);
static void _boxes_spice_display_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_display_set_config (BoxesDisplay* self, BoxesBoxConfig* value);
BoxesSpiceDisplay* boxes_spice_display_new_with_uri (BoxesMachine* machine, BoxesBoxConfig* config, const gchar* uri);
BoxesSpiceDisplay* boxes_spice_display_construct_with_uri (GType object_type, BoxesMachine* machine, BoxesBoxConfig* config, const gchar* uri);
static GtkWidget* boxes_spice_display_real_get_display (BoxesDisplay* base, gint n);
static void ___lambda114_ (BoxesSpiceDisplay* self, gint status);
void boxes_display_set_mouse_grabbed (BoxesDisplay* self, gboolean value);
static void ____lambda114__spice_display_mouse_grab (SpiceDisplay* _sender, gint grabbed, gpointer self);
static void ___lambda115_ (BoxesSpiceDisplay* self, gint status);
void boxes_display_set_keyboard_grabbed (BoxesDisplay* self, gboolean value);
static void ____lambda115__spice_display_keyboard_grab (SpiceDisplay* _sender, gint grabbed, gpointer self);
static gboolean boxes_spice_display_has_usb_device_connected (BoxesSpiceDisplay* self);
static SpiceUsbDevice* _vala_SpiceUsbDevice_copy (SpiceUsbDevice* self);
static void _vala_SpiceUsbDevice_free (SpiceUsbDevice* self);
static gboolean boxes_spice_display_real_should_keep_alive (BoxesDisplay* base);
static void boxes_spice_display_real_set_enable_audio (BoxesDisplay* base, gboolean enable);
static void boxes_spice_display_real_set_enable_inputs (BoxesDisplay* base, GtkWidget* widget, gboolean enable);
static GdkPixbuf* boxes_spice_display_real_get_pixbuf (BoxesDisplay* base, gint n, GError** error);
static void boxes_spice_display_real_collect_logs (BoxesDisplay* base, GString* builder);
gchar* boxes_display_get_uri (BoxesDisplay* self);
static void boxes_spice_display_real_connect_it (BoxesDisplay* base, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target, GError** error);
static Block65Data* block65_data_ref (Block65Data* _data65_);
static void block65_data_unref (void * _userdata_);
static void ___lambda116_ (Block65Data* _data65_, SpiceChannel* channel);
static Block66Data* block66_data_ref (Block66Data* _data66_);
static void block66_data_unref (void * _userdata_);
static void ___lambda117_ (Block66Data* _data66_);
static void ____lambda117__spice_channel_open_fd (SpiceChannel* _sender, gint with_tls, gpointer self);
static void boxes_spice_display_main_event (BoxesSpiceDisplay* self, SpiceChannelEvent event);
static void _boxes_spice_display_main_event_spice_channel_channel_event (SpiceChannel* _sender, SpiceChannelEvent event, gpointer self);
static void ___lambda118_ (BoxesSpiceDisplay* self);
void boxes_display_set_can_grab_mouse (BoxesDisplay* self, gboolean value);
static void ____lambda118__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static Block67Data* block67_data_ref (Block67Data* _data67_);
static void block67_data_unref (void * _userdata_);
void boxes_display_access_start (BoxesDisplay* self);
static void ___lambda119_ (Block67Data* _data67_);
static void ____lambda119__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda116__spice_session_channel_new (SpiceSession* _sender, SpiceChannel* channel, gpointer self);
static void ___lambda120_ (BoxesSpiceDisplay* self, SpiceChannel* channel);
void boxes_display_access_finish (BoxesDisplay* self);
static void ____lambda120__spice_session_channel_destroy (SpiceSession* _sender, SpiceChannel* channel, gpointer self);
const gchar* boxes_display_get_password (BoxesDisplay* self);
static void boxes_spice_display_real_disconnect_it (BoxesDisplay* base);
void boxes_display_set_need_password (BoxesDisplay* self, gboolean value);
static GList* boxes_spice_display_real_get_properties (BoxesDisplay* base, BoxesPropertiesPage page, PropertyCreationFlag* flags);
BoxesProperty* boxes_iproperties_provider_add_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, GtkWidget* widget, GtkWidget* extra_widget);
static Block68Data* block68_data_ref (Block68Data* _data68_);
static void block68_data_unref (void * _userdata_);
static GPtrArray* boxes_spice_display_get_usb_devices (BoxesSpiceDisplay* self, SpiceUsbDeviceManager* manager);
static Block69Data* block69_data_ref (Block69Data* _data69_);
static void block69_data_unref (void * _userdata_);
static gint ___lambda1__gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self);
static gint ____lambda121_ (SpiceUsbDevice* a, SpiceUsbDevice* b);
static gint _____lambda121__gcompare_func (gconstpointer a, gconstpointer b);
static Block70Data* block70_data_ref (Block70Data* _data70_);
static void block70_data_unref (void * _userdata_);
static void _______lambda122_ (Block70Data* _data70_);
static void ___lambda123_ (Block70Data* _data70_, GObject* obj, GAsyncResult* res);
static void ____lambda123__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void ________lambda122__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda124_ (Block68Data* _data68_, SpiceUsbDeviceManager* manager, SpiceUsbDevice* dev);
static void _____lambda124__spice_usb_device_manager_device_added (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, gpointer self);
static void ____lambda125_ (Block68Data* _data68_, SpiceUsbDeviceManager* manager, SpiceUsbDevice* dev);
static void _____lambda125__spice_usb_device_manager_device_removed (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, gpointer self);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void boxes_spice_display_real_send_keys (BoxesDisplay* base, guint* keyvals, int keyvals_length1);
static void __vala_SpiceUsbDevice_free0_ (gpointer var);
static gboolean boxes_spice_display_is_usb_kbd_or_mouse (BoxesSpiceDisplay* self, guint8 class, guint8 subclass, guint8 protocol);
GByteArray* boxes_spice_display_get_ca_cert (BoxesSpiceDisplay* self);
void boxes_spice_display_set_ca_cert (BoxesSpiceDisplay* self, GByteArray* value);
static GObject * boxes_spice_display_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_spice_display____lambda126_ (BoxesSpiceDisplay* self, SpiceUsbDevice* dev, GError* err);
static void __boxes_spice_display____lambda126__spice_usb_device_manager_device_error (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, GError* _error_, gpointer self);
static void _boxes_spice_display___lambda127_ (BoxesSpiceDisplay* self);
static void __boxes_spice_display___lambda127__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_spice_display_finalize (GObject* obj);
const gchar* boxes_display_get_protocol (BoxesDisplay* self);
static void _vala_boxes_spice_display_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_spice_display_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
void spice_validate_uri (const gchar* uri_as_text, gint** port, gint** tls_port, GError** error);
static gint* _int_dup (gint* self);


static void _vala_BoxesBoxConfigSyncProperty_array_free (BoxesBoxConfigSyncProperty* array, gint array_length) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (array != NULL) {
#line 360 "spice-display.c"
		int i;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			boxes_box_config_sync_property_destroy (&array[i]);
#line 366 "spice-display.c"
		}
	}
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_free (array);
#line 371 "spice-display.c"
}


static void boxes_spice_display_ui_state_changed (BoxesSpiceDisplay* self) {
	BoxesMachine* _tmp0_ = NULL;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->machine;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp2_ == BOXES_UI_STATE_DISPLAY) {
#line 389 "spice-display.c"
		SpiceDisplay* display = NULL;
		GtkWidget* _tmp3_ = NULL;
		SpiceDisplay* _tmp4_ = NULL;
		SpiceDisplay* _tmp5_ = NULL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp3_ = boxes_display_get_display ((BoxesDisplay*) self, 0);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp4_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp3_) : NULL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp4_ == NULL) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (_tmp3_);
#line 402 "spice-display.c"
		}
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		display = _tmp4_;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp5_ = display;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp5_, "resize-guest", TRUE, NULL);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (display);
#line 412 "spice-display.c"
	}
}


static gchar* boxes_spice_display_get_box_name (BoxesSpiceDisplay* self) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	BoxesBoxConfig* _tmp1_ = NULL;
	BoxesBoxConfig* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp7_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = boxes_display_get_config ((BoxesDisplay*) self);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = boxes_box_config_get_last_seen_name (_tmp2_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = _tmp3_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _tmp4_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp0_ == NULL) {
#line 439 "spice-display.c"
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp5_ = _ ("Unknown");
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = g_strdup (_tmp5_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp0_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp0_ = _tmp6_;
#line 450 "spice-display.c"
	}
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp7_ = _tmp0_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = NULL;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = _tmp7_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp0_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 462 "spice-display.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return self ? g_object_ref (self) : NULL;
#line 469 "spice-display.c"
}


static void boxes_spice_display_main_cleanup (BoxesSpiceDisplay* self) {
	SpiceMainChannel* _tmp0_ = NULL;
	GObject* o = NULL;
	SpiceMainChannel* _tmp1_ = NULL;
	GObject* _tmp2_ = NULL;
	GObject* _tmp3_ = NULL;
	gulong _tmp4_ = 0UL;
	GObject* _tmp5_ = NULL;
	gulong _tmp6_ = 0UL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->main_channel;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp0_ == NULL) {
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		return;
#line 490 "spice-display.c"
	}
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = self->priv->main_channel;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, G_TYPE_OBJECT) ? ((GObject*) _tmp1_) : NULL);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	o = _tmp2_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = o;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = self->priv->main_event_id;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_signal_handler_disconnect (_tmp3_, _tmp4_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->main_event_id = (gulong) 0;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5_ = o;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp6_ = self->priv->main_mouse_mode_id;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_signal_handler_disconnect (_tmp5_, _tmp6_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->main_mouse_mode_id = (gulong) 0;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->main_channel);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->main_channel = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (o);
#line 520 "spice-display.c"
}


static void _boxes_spice_display_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_ui_state_changed ((BoxesSpiceDisplay*) self);
#line 527 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_construct (GType object_type, BoxesMachine* machine, BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port, const gchar* host_subject) {
	BoxesSpiceDisplay * self = NULL;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	BoxesMachine* _tmp2_ = NULL;
	BoxesMachine* _tmp3_ = NULL;
	BoxesBoxConfig* _tmp4_ = NULL;
	SpiceSession* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	gint _tmp12_ = 0;
	const gchar* _tmp17_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (config != NULL, NULL);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (host != NULL, NULL);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = port;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = tls_port;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_vala_return_val_if_fail ((_tmp0_ != 0) || (_tmp1_ != 0), "port != 0 || tls_port != 0", NULL);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) boxes_display_construct (object_type);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = machine;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->machine = _tmp2_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = machine;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_signal_connect_object ((GObject*) _tmp3_, "notify::ui-state", (GCallback) _boxes_spice_display_ui_state_changed_g_object_notify, self, 0);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = config;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_display_set_config ((BoxesDisplay*) self, _tmp4_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5_ = self->priv->session;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp6_ = host;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp5_, "host", _tmp6_, NULL);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp7_ = port;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp7_ != 0) {
#line 579 "spice-display.c"
		SpiceSession* _tmp8_ = NULL;
		gint _tmp9_ = 0;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp8_ = self->priv->session;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp9_ = port;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp10_ = g_strdup_printf ("%i", _tmp9_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp11_ = _tmp10_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp8_, "port", _tmp11_, NULL);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp11_);
#line 596 "spice-display.c"
	}
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp12_ = tls_port;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp12_ != 0) {
#line 602 "spice-display.c"
		SpiceSession* _tmp13_ = NULL;
		gint _tmp14_ = 0;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp13_ = self->priv->session;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp14_ = tls_port;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp15_ = g_strdup_printf ("%i", _tmp14_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp16_ = _tmp15_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp13_, "tls-port", _tmp16_, NULL);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp16_);
#line 619 "spice-display.c"
	}
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp17_ = host_subject;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp17_ != NULL) {
#line 625 "spice-display.c"
		SpiceSession* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp18_ = self->priv->session;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp19_ = host_subject;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp18_, "cert-subject", _tmp19_, NULL);
#line 634 "spice-display.c"
	} else {
		SpiceSession* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp20_ = self->priv->session;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp21_ = g_getenv ("BOXES_SPICE_HOST_SUBJECT");
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp20_, "cert-subject", _tmp21_, NULL);
#line 644 "spice-display.c"
	}
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return self;
#line 648 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_new (BoxesMachine* machine, BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port, const gchar* host_subject) {
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return boxes_spice_display_construct (BOXES_TYPE_SPICE_DISPLAY, machine, config, host, port, tls_port, host_subject);
#line 655 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_construct_with_uri (GType object_type, BoxesMachine* machine, BoxesBoxConfig* config, const gchar* uri) {
	BoxesSpiceDisplay * self = NULL;
	BoxesMachine* _tmp0_ = NULL;
	BoxesMachine* _tmp1_ = NULL;
	BoxesBoxConfig* _tmp2_ = NULL;
	SpiceSession* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (config != NULL, NULL);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (uri != NULL, NULL);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) boxes_display_construct (object_type);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = machine;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->machine = _tmp0_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = machine;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_signal_connect_object ((GObject*) _tmp1_, "notify::ui-state", (GCallback) _boxes_spice_display_ui_state_changed_g_object_notify, self, 0);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = config;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_display_set_config ((BoxesDisplay*) self, _tmp2_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = self->priv->session;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = uri;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp3_, "uri", _tmp4_, NULL);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return self;
#line 694 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_new_with_uri (BoxesMachine* machine, BoxesBoxConfig* config, const gchar* uri) {
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return boxes_spice_display_construct_with_uri (BOXES_TYPE_SPICE_DISPLAY, machine, config, uri);
#line 701 "spice-display.c"
}


static void ___lambda114_ (BoxesSpiceDisplay* self, gint status) {
	gint _tmp0_ = 0;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = status;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_display_set_mouse_grabbed ((BoxesDisplay*) self, _tmp0_ != 0);
#line 711 "spice-display.c"
}


static void ____lambda114__spice_display_mouse_grab (SpiceDisplay* _sender, gint grabbed, gpointer self) {
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	___lambda114_ ((BoxesSpiceDisplay*) self, grabbed);
#line 718 "spice-display.c"
}


static void ___lambda115_ (BoxesSpiceDisplay* self, gint status) {
	gint _tmp0_ = 0;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = status;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_display_set_keyboard_grabbed ((BoxesDisplay*) self, _tmp0_ != 0);
#line 728 "spice-display.c"
}


static void ____lambda115__spice_display_keyboard_grab (SpiceDisplay* _sender, gint grabbed, gpointer self) {
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	___lambda115_ ((BoxesSpiceDisplay*) self, grabbed);
#line 735 "spice-display.c"
}


static GtkWidget* boxes_spice_display_real_get_display (BoxesDisplay* base, gint n) {
	BoxesSpiceDisplay * self;
	GtkWidget* result = NULL;
	SpiceDisplay* display = NULL;
	GHashTable* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gconstpointer _tmp2_ = NULL;
	GtkWidget* _tmp3_ = NULL;
	SpiceDisplay* _tmp4_ = NULL;
	SpiceDisplay* _tmp5_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = ((BoxesDisplay*) self)->displays;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = n;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = g_hash_table_lookup (_tmp0_, (gpointer) ((gintptr) _tmp1_));
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = (GtkWidget*) _tmp2_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp3_) : NULL);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	display = _tmp4_;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5_ = display;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp5_ == NULL) {
#line 767 "spice-display.c"
		SpiceSession* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		SpiceDisplay* _tmp8_ = NULL;
		SpiceDisplay* _tmp9_ = NULL;
		SpiceDisplay* _tmp10_ = NULL;
		BoxesBoxConfig* _tmp11_ = NULL;
		BoxesBoxConfig* _tmp12_ = NULL;
		BoxesBoxConfigSyncProperty* _tmp13_ = NULL;
		gint _tmp13__length1 = 0;
		SpiceDisplay* _tmp14_ = NULL;
		GHashTable* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		SpiceDisplay* _tmp17_ = NULL;
		GtkWidget* _tmp18_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = self->priv->session;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp7_ = n;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp8_ = spice_display_new (_tmp6_, _tmp7_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_ref_sink (_tmp8_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (display);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		display = _tmp8_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp9_ = display;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_connect_object (_tmp9_, "mouse-grab", (GCallback) ____lambda114__spice_display_mouse_grab, self, 0);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp10_ = display;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_connect_object (_tmp10_, "keyboard-grab", (GCallback) ____lambda115__spice_display_keyboard_grab, self, 0);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp11_ = boxes_display_get_config ((BoxesDisplay*) self);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp12_ = _tmp11_;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp13_ = self->priv->display_sync_properties;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp13__length1 = self->priv->display_sync_properties_length1;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		boxes_box_config_sync_properties (_tmp12_, (GObject*) self, _tmp13_, _tmp13__length1);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp14_ = display;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp14_, "scaling", TRUE, NULL);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp15_ = ((BoxesDisplay*) self)->displays;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp16_ = n;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp17_ = display;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp18_ = _g_object_ref0 ((GtkWidget*) _tmp17_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_hash_table_replace (_tmp15_, (gpointer) ((gintptr) _tmp16_), _tmp18_);
#line 826 "spice-display.c"
	}
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = (GtkWidget*) display;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 832 "spice-display.c"
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_ = 0U;
#line 4428 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4428 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4428 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4428 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	return result;
#line 847 "spice-display.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_ = 0;
#line 4429 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4429 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp0_ = value;
#line 4429 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 859 "spice-display.c"
}


static SpiceUsbDevice* _vala_SpiceUsbDevice_copy (SpiceUsbDevice* self) {
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return g_boxed_copy (spice_usb_device_get_type (), self);
#line 866 "spice-display.c"
}


static gpointer __vala_SpiceUsbDevice_copy0 (gpointer self) {
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return self ? _vala_SpiceUsbDevice_copy (self) : NULL;
#line 873 "spice-display.c"
}


static void _vala_SpiceUsbDevice_free (SpiceUsbDevice* self) {
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_boxed_free (spice_usb_device_get_type (), self);
#line 880 "spice-display.c"
}


static gboolean boxes_spice_display_has_usb_device_connected (BoxesSpiceDisplay* self) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 889 "spice-display.c"
	{
		SpiceUsbDeviceManager* manager = NULL;
		SpiceSession* _tmp0_ = NULL;
		SpiceUsbDeviceManager* _tmp1_ = NULL;
		SpiceUsbDeviceManager* _tmp2_ = NULL;
		GPtrArray* devs = NULL;
		SpiceUsbDeviceManager* _tmp3_ = NULL;
		GPtrArray* _tmp4_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp0_ = self->priv->session;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp1_ = spice_usb_device_manager_get (_tmp0_, &_inner_error_);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp2_ = _g_object_ref0 (_tmp1_);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		manager = _tmp2_;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 908 "spice-display.c"
			goto __catch73_g_error;
		}
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp3_ = manager;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp4_ = spice_usb_device_manager_get_devices (_tmp3_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		devs = _tmp4_;
#line 917 "spice-display.c"
		{
			gint i = 0;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			i = 0;
#line 922 "spice-display.c"
			{
				gboolean _tmp5_ = FALSE;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp5_ = TRUE;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				while (TRUE) {
#line 929 "spice-display.c"
					gint _tmp7_ = 0;
					GPtrArray* _tmp8_ = NULL;
					gint _tmp9_ = 0;
					gint _tmp10_ = 0;
					SpiceUsbDevice* dev = NULL;
					GPtrArray* _tmp11_ = NULL;
					gint _tmp12_ = 0;
					gconstpointer _tmp13_ = NULL;
					SpiceUsbDevice* _tmp14_ = NULL;
					SpiceUsbDeviceManager* _tmp15_ = NULL;
					SpiceUsbDevice* _tmp16_ = NULL;
					gboolean _tmp17_ = FALSE;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					if (!_tmp5_) {
#line 944 "spice-display.c"
						gint _tmp6_ = 0;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp6_ = i;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						i = _tmp6_ + 1;
#line 950 "spice-display.c"
					}
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp5_ = FALSE;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp7_ = i;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp8_ = devs;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp9_ = g_ptr_array_get_length (_tmp8_);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp10_ = _tmp9_;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					if (!(_tmp7_ < _tmp10_)) {
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						break;
#line 966 "spice-display.c"
					}
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp11_ = devs;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp12_ = i;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp13_ = g_ptr_array_index (_tmp11_, (guint) _tmp12_);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp14_ = __vala_SpiceUsbDevice_copy0 ((SpiceUsbDevice*) _tmp13_);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					dev = _tmp14_;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp15_ = manager;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp16_ = dev;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp17_ = spice_usb_device_manager_is_device_connected (_tmp15_, _tmp16_);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					if (_tmp17_) {
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						result = TRUE;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						__vala_SpiceUsbDevice_free0 (dev);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_g_ptr_array_unref0 (devs);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_g_object_unref0 (manager);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						return result;
#line 996 "spice-display.c"
					}
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					__vala_SpiceUsbDevice_free0 (dev);
#line 1000 "spice-display.c"
				}
			}
		}
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_ptr_array_unref0 (devs);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (manager);
#line 1008 "spice-display.c"
	}
	goto __finally73;
	__catch73_g_error:
	{
		GError* _error_ = NULL;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_error_ = _inner_error_;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (_error_);
#line 1020 "spice-display.c"
	}
	__finally73:
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		return FALSE;
#line 1031 "spice-display.c"
	}
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = FALSE;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 1037 "spice-display.c"
}


static gboolean boxes_spice_display_real_should_keep_alive (BoxesDisplay* base) {
	BoxesSpiceDisplay * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = self->priv->closed;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (!_tmp1_) {
#line 1052 "spice-display.c"
		gboolean _tmp2_ = FALSE;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp2_ = boxes_spice_display_has_usb_device_connected (self);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp0_ = _tmp2_;
#line 1058 "spice-display.c"
	} else {
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp0_ = FALSE;
#line 1062 "spice-display.c"
	}
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = _tmp0_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 1068 "spice-display.c"
}


static void boxes_spice_display_real_set_enable_audio (BoxesDisplay* base, gboolean enable) {
	BoxesSpiceDisplay * self;
	SpiceSession* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = enable;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp0_, "enable-audio", _tmp1_, NULL);
#line 1084 "spice-display.c"
}


static void boxes_spice_display_real_set_enable_inputs (BoxesDisplay* base, GtkWidget* widget, gboolean enable) {
	BoxesSpiceDisplay * self;
	GtkWidget* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (widget != NULL);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = widget;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = enable;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_set (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp0_) : NULL, "disable-inputs", !_tmp1_, NULL);
#line 1102 "spice-display.c"
}


static GdkPixbuf* boxes_spice_display_real_get_pixbuf (BoxesDisplay* base, gint n, GError** error) {
	BoxesSpiceDisplay * self;
	GdkPixbuf* result = NULL;
	SpiceDisplay* display = NULL;
	gint _tmp0_ = 0;
	GtkWidget* _tmp1_ = NULL;
	SpiceDisplay* _tmp2_ = NULL;
	SpiceDisplay* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	SpiceDisplay* _tmp6_ = NULL;
	GdkPixbuf* _tmp7_ = NULL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = n;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = boxes_display_get_display ((BoxesDisplay*) self, _tmp0_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp1_) : NULL;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp2_ == NULL) {
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_tmp1_);
#line 1130 "spice-display.c"
	}
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	display = _tmp2_;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = display;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp3_, "ready", &_tmp4_, NULL);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5_ = _tmp4_;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (!_tmp5_) {
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		result = NULL;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (display);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		return result;
#line 1148 "spice-display.c"
	}
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp6_ = display;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp7_ = spice_display_get_pixbuf (_tmp6_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = _tmp7_;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (display);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 1160 "spice-display.c"
}


static void boxes_spice_display_real_collect_logs (BoxesDisplay* base, GString* builder) {
	BoxesSpiceDisplay * self;
	GString* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	SpiceGtkSession* _tmp4_ = NULL;
	SpiceMainChannel* _tmp10_ = NULL;
	GError * _inner_error_ = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (builder != NULL);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = builder;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = boxes_display_get_uri ((BoxesDisplay*) self);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _tmp2_;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_string_append_printf (_tmp0_, "URI: %s\n", _tmp3_);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp3_);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = self->priv->gtk_session;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp4_ != NULL) {
#line 1193 "spice-display.c"
		const gchar* _tmp5_ = NULL;
		SpiceGtkSession* _tmp6_ = NULL;
		gboolean _tmp7_ = FALSE;
		gboolean _tmp8_ = FALSE;
		GString* _tmp9_ = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = self->priv->gtk_session;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp6_, "auto-clipboard", &_tmp7_, NULL);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp8_ = _tmp7_;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp8_) {
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp5_ = "yes";
#line 1209 "spice-display.c"
		} else {
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp5_ = "no";
#line 1213 "spice-display.c"
		}
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp9_ = builder;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp9_, "Auto clipboard sync: %s\n", _tmp5_);
#line 1219 "spice-display.c"
	}
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp10_ = self->priv->main_channel;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp10_ != NULL) {
#line 1225 "spice-display.c"
		GString* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		SpiceMainChannel* _tmp14_ = NULL;
		gint _tmp15_ = 0;
		gint _tmp16_ = 0;
		GString* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
		SpiceMainChannel* _tmp19_ = NULL;
		gboolean _tmp20_ = FALSE;
		gboolean _tmp21_ = FALSE;
		GString* _tmp22_ = NULL;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp11_ = builder;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp12_ = spice_util_get_version_string ();
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp11_, "Spice-gtk version %s\n", _tmp12_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp14_ = self->priv->main_channel;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp14_, "mouse-mode", &_tmp15_, NULL);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp16_ = _tmp15_;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp16_ == 1) {
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp13_ = "server";
#line 1254 "spice-display.c"
		} else {
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp13_ = "client";
#line 1258 "spice-display.c"
		}
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp17_ = builder;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp17_, "Mouse mode: %s\n", _tmp13_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp19_ = self->priv->main_channel;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp19_, "agent-connected", &_tmp20_, NULL);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp21_ = _tmp20_;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp21_) {
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp18_ = "connected";
#line 1274 "spice-display.c"
		} else {
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp18_ = "disconnected";
#line 1278 "spice-display.c"
		}
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp22_ = builder;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp22_, "Agent: %s\n", _tmp18_);
#line 1284 "spice-display.c"
	}
	{
		SpiceUsbDeviceManager* manager = NULL;
		SpiceSession* _tmp23_ = NULL;
		SpiceUsbDeviceManager* _tmp24_ = NULL;
		SpiceUsbDeviceManager* _tmp25_ = NULL;
		GPtrArray* devs = NULL;
		SpiceUsbDeviceManager* _tmp26_ = NULL;
		GPtrArray* _tmp27_ = NULL;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp23_ = self->priv->session;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp24_ = spice_usb_device_manager_get (_tmp23_, &_inner_error_);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp25_ = _g_object_ref0 (_tmp24_);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		manager = _tmp25_;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1304 "spice-display.c"
			goto __catch74_g_error;
		}
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp26_ = manager;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp27_ = spice_usb_device_manager_get_devices (_tmp26_);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		devs = _tmp27_;
#line 1313 "spice-display.c"
		{
			gint i = 0;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			i = 0;
#line 1318 "spice-display.c"
			{
				gboolean _tmp28_ = FALSE;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp28_ = TRUE;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				while (TRUE) {
#line 1325 "spice-display.c"
					gint _tmp30_ = 0;
					GPtrArray* _tmp31_ = NULL;
					gint _tmp32_ = 0;
					gint _tmp33_ = 0;
					SpiceUsbDevice* dev = NULL;
					GPtrArray* _tmp34_ = NULL;
					gint _tmp35_ = 0;
					gconstpointer _tmp36_ = NULL;
					SpiceUsbDevice* _tmp37_ = NULL;
					SpiceUsbDeviceManager* _tmp38_ = NULL;
					SpiceUsbDevice* _tmp39_ = NULL;
					gboolean _tmp40_ = FALSE;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					if (!_tmp28_) {
#line 1340 "spice-display.c"
						gint _tmp29_ = 0;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp29_ = i;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						i = _tmp29_ + 1;
#line 1346 "spice-display.c"
					}
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp28_ = FALSE;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp30_ = i;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp31_ = devs;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp32_ = g_ptr_array_get_length (_tmp31_);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp33_ = _tmp32_;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					if (!(_tmp30_ < _tmp33_)) {
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						break;
#line 1362 "spice-display.c"
					}
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp34_ = devs;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp35_ = i;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp36_ = g_ptr_array_index (_tmp34_, (guint) _tmp35_);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp37_ = __vala_SpiceUsbDevice_copy0 ((SpiceUsbDevice*) _tmp36_);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					dev = _tmp37_;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp38_ = manager;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp39_ = dev;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp40_ = spice_usb_device_manager_is_device_connected (_tmp38_, _tmp39_);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					if (_tmp40_) {
#line 1382 "spice-display.c"
						GString* _tmp41_ = NULL;
						SpiceUsbDevice* _tmp42_ = NULL;
						gchar* _tmp43_ = NULL;
						gchar* _tmp44_ = NULL;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp41_ = builder;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp42_ = dev;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp43_ = spice_usb_device_get_description (_tmp42_, "%s %s %s at %d-%d");
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp44_ = _tmp43_;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						g_string_append_printf (_tmp41_, "USB device redirected: %s\n", _tmp44_);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_g_free0 (_tmp44_);
#line 1399 "spice-display.c"
					}
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					__vala_SpiceUsbDevice_free0 (dev);
#line 1403 "spice-display.c"
				}
			}
		}
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_ptr_array_unref0 (devs);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (manager);
#line 1411 "spice-display.c"
	}
	goto __finally74;
	__catch74_g_error:
	{
		GError* _error_ = NULL;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_error_ = _inner_error_;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (_error_);
#line 1423 "spice-display.c"
	}
	__finally74:
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		return;
#line 1434 "spice-display.c"
	}
}


static Block65Data* block65_data_ref (Block65Data* _data65_) {
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data65_->_ref_count_);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return _data65_;
#line 1444 "spice-display.c"
}


static void block65_data_unref (void * _userdata_) {
	Block65Data* _data65_;
	_data65_ = (Block65Data*) _userdata_;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data65_->_ref_count_)) {
#line 1453 "spice-display.c"
		BoxesSpiceDisplay* self;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self = _data65_->self;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (self);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block65Data, _data65_);
#line 1461 "spice-display.c"
	}
}


static Block66Data* block66_data_ref (Block66Data* _data66_) {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data66_->_ref_count_);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return _data66_;
#line 1471 "spice-display.c"
}


static void block66_data_unref (void * _userdata_) {
	Block66Data* _data66_;
	_data66_ = (Block66Data*) _userdata_;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data66_->_ref_count_)) {
#line 1480 "spice-display.c"
		BoxesSpiceDisplay* self;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self = _data66_->_data65_->self;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data66_->channel);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		block65_data_unref (_data66_->_data65_);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_data66_->_data65_ = NULL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block66Data, _data66_);
#line 1492 "spice-display.c"
	}
}


static void ___lambda117_ (Block66Data* _data66_) {
	Block65Data* _data65_;
	BoxesSpiceDisplay* self;
	gint fd = 0;
	BoxesDisplayOpenFDFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	gint _tmp1_ = 0;
	SpiceChannel* _tmp2_ = NULL;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data65_ = _data66_->_data65_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = _data65_->self;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data65_->open_fd;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0__target = _data65_->open_fd_target;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _tmp0_ (_tmp0__target);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	fd = _tmp1_;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _data66_->channel;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	spice_channel_open_fd (_tmp2_, fd);
#line 1521 "spice-display.c"
}


static void ____lambda117__spice_channel_open_fd (SpiceChannel* _sender, gint with_tls, gpointer self) {
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	___lambda117_ (self);
#line 1528 "spice-display.c"
}


static void _boxes_spice_display_main_event_spice_channel_channel_event (SpiceChannel* _sender, SpiceChannelEvent event, gpointer self) {
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_main_event ((BoxesSpiceDisplay*) self, event);
#line 1535 "spice-display.c"
}


static void ___lambda118_ (BoxesSpiceDisplay* self) {
	SpiceMainChannel* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->main_channel;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp0_, "mouse-mode", &_tmp1_, NULL);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_display_set_can_grab_mouse ((BoxesDisplay*) self, _tmp2_ != 2);
#line 1551 "spice-display.c"
}


static void ____lambda118__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	___lambda118_ ((BoxesSpiceDisplay*) self);
#line 1558 "spice-display.c"
}


static Block67Data* block67_data_ref (Block67Data* _data67_) {
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data67_->_ref_count_);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return _data67_;
#line 1567 "spice-display.c"
}


static void block67_data_unref (void * _userdata_) {
	Block67Data* _data67_;
	_data67_ = (Block67Data*) _userdata_;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data67_->_ref_count_)) {
#line 1576 "spice-display.c"
		BoxesSpiceDisplay* self;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self = _data67_->_data66_->_data65_->self;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data67_->display);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		block66_data_unref (_data67_->_data66_);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_data67_->_data66_ = NULL;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block67Data, _data67_);
#line 1588 "spice-display.c"
	}
}


static void ___lambda119_ (Block67Data* _data67_) {
	Block66Data* _data66_;
	Block65Data* _data65_;
	BoxesSpiceDisplay* self;
	SpiceDisplay* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data66_ = _data67_->_data66_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data65_ = _data66_->_data65_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = _data65_->self;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data67_->display;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp0_, "ready", &_tmp1_, NULL);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp2_) {
#line 1614 "spice-display.c"
		SpiceDisplay* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gint _tmp5_ = 0;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp3_ = _data67_->display;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp3_, "channel-id", &_tmp4_, NULL);
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp5_ = _tmp4_;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_emit_by_name ((BoxesDisplay*) self, "show", _tmp5_);
#line 1626 "spice-display.c"
	} else {
		SpiceDisplay* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		gint _tmp8_ = 0;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = _data67_->display;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp6_, "channel-id", &_tmp7_, NULL);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp8_ = _tmp7_;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_emit_by_name ((BoxesDisplay*) self, "hide", _tmp8_);
#line 1639 "spice-display.c"
	}
}


static void ____lambda119__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	___lambda119_ (self);
#line 1647 "spice-display.c"
}


static void ___lambda116_ (Block65Data* _data65_, SpiceChannel* channel) {
	BoxesSpiceDisplay* self;
	Block66Data* _data66_;
	SpiceChannel* _tmp0_ = NULL;
	SpiceChannel* _tmp1_ = NULL;
	gint id = 0;
	SpiceChannel* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	BoxesDisplayOpenFDFunc _tmp5_ = NULL;
	void* _tmp5__target = NULL;
	SpiceChannel* _tmp7_ = NULL;
	SpiceChannel* _tmp17_ = NULL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = _data65_->self;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (channel != NULL);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data66_ = g_slice_new0 (Block66Data);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data66_->_ref_count_ = 1;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data66_->_data65_ = block65_data_ref (_data65_);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = channel;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (_data66_->channel);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data66_->channel = _tmp1_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _data66_->channel;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp2_, "channel-id", &_tmp3_, NULL);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = _tmp3_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	id = _tmp4_;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5_ = _data65_->open_fd;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5__target = _data65_->open_fd_target;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp5_ != NULL) {
#line 1696 "spice-display.c"
		SpiceChannel* _tmp6_ = NULL;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = _data66_->channel;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_connect_data (_tmp6_, "open-fd", (GCallback) ____lambda117__spice_channel_open_fd, block66_data_ref (_data66_), (GClosureNotify) block66_data_unref, 0);
#line 1702 "spice-display.c"
	}
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp7_ = _data66_->channel;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, spice_main_channel_get_type ())) {
#line 1708 "spice-display.c"
		SpiceChannel* _tmp8_ = NULL;
		SpiceMainChannel* _tmp9_ = NULL;
		SpiceMainChannel* _tmp10_ = NULL;
		gulong _tmp11_ = 0UL;
		SpiceMainChannel* _tmp12_ = NULL;
		gulong _tmp13_ = 0UL;
		SpiceMainChannel* _tmp14_ = NULL;
		gint _tmp15_ = 0;
		gint _tmp16_ = 0;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp8_ = _data66_->channel;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, spice_main_channel_get_type ()) ? ((SpiceMainChannel*) _tmp8_) : NULL);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (self->priv->main_channel);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self->priv->main_channel = _tmp9_;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp10_ = self->priv->main_channel;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp11_ = g_signal_connect_object ((SpiceChannel*) _tmp10_, "channel-event", (GCallback) _boxes_spice_display_main_event_spice_channel_channel_event, self, 0);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self->priv->main_event_id = _tmp11_;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp12_ = self->priv->main_channel;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp13_ = g_signal_connect_object ((GObject*) _tmp12_, "notify::mouse-mode", (GCallback) ____lambda118__g_object_notify, self, 0);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self->priv->main_mouse_mode_id = _tmp13_;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp14_ = self->priv->main_channel;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp14_, "mouse-mode", &_tmp15_, NULL);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp16_ = _tmp15_;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		boxes_display_set_can_grab_mouse ((BoxesDisplay*) self, _tmp16_ != 2);
#line 1746 "spice-display.c"
	}
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp17_ = _data66_->channel;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, spice_display_channel_get_type ())) {
#line 1752 "spice-display.c"
		Block67Data* _data67_;
		gint _tmp18_ = 0;
		gint _tmp19_ = 0;
		GtkWidget* _tmp20_ = NULL;
		SpiceDisplay* _tmp21_ = NULL;
		SpiceDisplay* _tmp22_ = NULL;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_data67_ = g_slice_new0 (Block67Data);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_data67_->_ref_count_ = 1;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_data67_->_data66_ = block66_data_ref (_data66_);
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp18_ = id;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp18_ != 0) {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			block67_data_unref (_data67_);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_data67_ = NULL;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			block66_data_unref (_data66_);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_data66_ = NULL;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			return;
#line 1779 "spice-display.c"
		}
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		boxes_display_access_start ((BoxesDisplay*) self);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp19_ = id;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp20_ = boxes_display_get_display ((BoxesDisplay*) self, _tmp19_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp21_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp20_) : NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp21_ == NULL) {
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (_tmp20_);
#line 1793 "spice-display.c"
		}
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_data67_->display = _tmp21_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp22_ = _data67_->display;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_connect_data ((GObject*) _tmp22_, "notify::ready", (GCallback) ____lambda119__g_object_notify, block67_data_ref (_data67_), (GClosureNotify) block67_data_unref, 0);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		block67_data_unref (_data67_);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_data67_ = NULL;
#line 1805 "spice-display.c"
	}
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	block66_data_unref (_data66_);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data66_ = NULL;
#line 1811 "spice-display.c"
}


static void ____lambda116__spice_session_channel_new (SpiceSession* _sender, SpiceChannel* channel, gpointer self) {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	___lambda116_ (self, channel);
#line 1818 "spice-display.c"
}


static void ___lambda120_ (BoxesSpiceDisplay* self, SpiceChannel* channel) {
	SpiceChannel* _tmp0_ = NULL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (channel != NULL);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = channel;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, spice_display_channel_get_type ())) {
#line 1830 "spice-display.c"
		SpiceDisplayChannel* display = NULL;
		SpiceChannel* _tmp1_ = NULL;
		SpiceDisplayChannel* _tmp2_ = NULL;
		SpiceDisplayChannel* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gint _tmp5_ = 0;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp1_ = channel;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, spice_display_channel_get_type ()) ? ((SpiceDisplayChannel*) _tmp1_) : NULL);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		display = _tmp2_;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp3_ = display;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_get ((SpiceChannel*) _tmp3_, "channel-id", &_tmp4_, NULL);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp5_ = _tmp4_;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_emit_by_name ((BoxesDisplay*) self, "hide", _tmp5_);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		boxes_display_access_finish ((BoxesDisplay*) self);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (display);
#line 1855 "spice-display.c"
	}
}


static void ____lambda120__spice_session_channel_destroy (SpiceSession* _sender, SpiceChannel* channel, gpointer self) {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	___lambda120_ ((BoxesSpiceDisplay*) self, channel);
#line 1863 "spice-display.c"
}


static void boxes_spice_display_real_connect_it (BoxesDisplay* base, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target, GError** error) {
	BoxesSpiceDisplay * self;
	Block65Data* _data65_;
	BoxesDisplayOpenFDFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	gboolean _tmp1_ = FALSE;
	gulong _tmp2_ = 0UL;
	gulong _tmp5_ = 0UL;
	SpiceSession* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	BoxesDisplayOpenFDFunc _tmp11_ = NULL;
	void* _tmp11__target = NULL;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data65_ = g_slice_new0 (Block65Data);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data65_->_ref_count_ = 1;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data65_->self = g_object_ref (self);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = open_fd;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0__target = open_fd_target;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data65_->open_fd = _tmp0_;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data65_->open_fd_target = _tmp0__target;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = ((BoxesDisplay*) self)->connected;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp1_) {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		block65_data_unref (_data65_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_data65_ = NULL;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		return;
#line 1906 "spice-display.c"
	}
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	((BoxesDisplay*) self)->connected = TRUE;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_main_cleanup (self);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = self->priv->channel_new_id;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp2_ == ((gulong) 0)) {
#line 1916 "spice-display.c"
		SpiceSession* _tmp3_ = NULL;
		gulong _tmp4_ = 0UL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp3_ = self->priv->session;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp4_ = g_signal_connect_data (_tmp3_, "channel-new", (GCallback) ____lambda116__spice_session_channel_new, block65_data_ref (_data65_), (GClosureNotify) block65_data_unref, 0);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self->priv->channel_new_id = _tmp4_;
#line 1925 "spice-display.c"
	}
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5_ = self->priv->channel_destroy_id;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp5_ == ((gulong) 0)) {
#line 1931 "spice-display.c"
		SpiceSession* _tmp6_ = NULL;
		gulong _tmp7_ = 0UL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = self->priv->session;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp7_ = g_signal_connect_object (_tmp6_, "channel-destroy", (GCallback) ____lambda120__spice_session_channel_destroy, self, 0);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self->priv->channel_destroy_id = _tmp7_;
#line 1940 "spice-display.c"
	}
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp8_ = self->priv->session;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp9_ = boxes_display_get_password ((BoxesDisplay*) self);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp10_ = _tmp9_;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp8_, "password", _tmp10_, NULL);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp11_ = _data65_->open_fd;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp11__target = _data65_->open_fd_target;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp11_ != NULL) {
#line 1956 "spice-display.c"
		SpiceSession* _tmp12_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp12_ = self->priv->session;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		spice_session_open_fd (_tmp12_, -1);
#line 1962 "spice-display.c"
	} else {
		SpiceSession* _tmp13_ = NULL;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp13_ = self->priv->session;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		spice_session_connect (_tmp13_);
#line 1969 "spice-display.c"
	}
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	block65_data_unref (_data65_);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data65_ = NULL;
#line 1975 "spice-display.c"
}


static void boxes_spice_display_real_disconnect_it (BoxesDisplay* base) {
	BoxesSpiceDisplay * self;
	SpiceSession* _tmp0_ = NULL;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	spice_session_disconnect (_tmp0_);
#line 1988 "spice-display.c"
}


static void boxes_spice_display_main_event (BoxesSpiceDisplay* self, SpiceChannelEvent event) {
	SpiceChannelEvent _tmp0_ = 0;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = event;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	switch (_tmp0_) {
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_CLOSED:
#line 2002 "spice-display.c"
		{
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			self->priv->closed = TRUE;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_signal_emit_by_name ((BoxesDisplay*) self, "disconnected", FALSE);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			break;
#line 2010 "spice-display.c"
		}
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_ERROR_AUTH:
#line 2014 "spice-display.c"
		{
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			boxes_display_set_need_password ((BoxesDisplay*) self, TRUE);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			break;
#line 2020 "spice-display.c"
		}
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_ERROR_CONNECT:
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_ERROR_TLS:
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_ERROR_LINK:
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_ERROR_IO:
#line 2030 "spice-display.c"
		{
			SpiceChannelEvent _tmp1_ = 0;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp1_ = event;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_debug ("spice-display.vala:274: main SPICE channel error: %d", (gint) _tmp1_);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			self->priv->closed = TRUE;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_signal_emit_by_name ((BoxesDisplay*) self, "disconnected", TRUE);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			break;
#line 2043 "spice-display.c"
		}
		default:
		{
			SpiceChannelEvent _tmp2_ = 0;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp2_ = event;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_debug ("spice-display.vala:280: unhandled main SPICE channel event: %d", (gint) _tmp2_);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			break;
#line 2054 "spice-display.c"
		}
	}
}


static Block68Data* block68_data_ref (Block68Data* _data68_) {
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data68_->_ref_count_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return _data68_;
#line 2065 "spice-display.c"
}


static void block68_data_unref (void * _userdata_) {
	Block68Data* _data68_;
	_data68_ = (Block68Data*) _userdata_;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data68_->_ref_count_)) {
#line 2074 "spice-display.c"
		BoxesSpiceDisplay* self;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self = _data68_->self;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data68_->usb_property);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data68_->manager);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (self);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block68Data, _data68_);
#line 2086 "spice-display.c"
	}
}


static Block69Data* block69_data_ref (Block69Data* _data69_) {
#line 4412 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	g_atomic_int_inc (&_data69_->_ref_count_);
#line 4412 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	return _data69_;
#line 2096 "spice-display.c"
}


static void block69_data_unref (void * _userdata_) {
	Block69Data* _data69_;
	_data69_ = (Block69Data*) _userdata_;
#line 4412 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	if (g_atomic_int_dec_and_test (&_data69_->_ref_count_)) {
#line 2105 "spice-display.c"
		GPtrArray* self;
#line 4412 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		self = _data69_->self;
#line 4412 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		_g_ptr_array_unref0 (self);
#line 4412 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
		g_slice_free (Block69Data, _data69_);
#line 2113 "spice-display.c"
	}
}


static gint __lambda1_ (Block69Data* _data69_, gconstpointer** a, gconstpointer** b) {
	GPtrArray* self;
	gint result = 0;
	GCompareFunc _tmp0_ = NULL;
	gconstpointer** _tmp1_ = NULL;
	gconstpointer** _tmp2_ = NULL;
	gint _tmp3_ = 0;
#line 4413 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	self = _data69_->self;
#line 4414 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp0_ = _data69_->compare_func;
#line 4414 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp1_ = a;
#line 4414 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp2_ = b;
#line 4414 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp3_ = _tmp0_ ((gconstpointer**) (*_tmp1_), (gconstpointer**) (*_tmp2_));
#line 4414 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	result = _tmp3_;
#line 4414 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	return result;
#line 2139 "spice-display.c"
}


static gint ___lambda1__gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gint result;
	result = __lambda1_ (self, a, b);
#line 4413 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	return result;
#line 2148 "spice-display.c"
}


static void vala_g_ptr_array_sort (GPtrArray* self, GCompareFunc compare_func) {
	Block69Data* _data69_;
	GCompareFunc _tmp0_ = NULL;
#line 4412 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4412 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	_data69_ = g_slice_new0 (Block69Data);
#line 4412 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	_data69_->_ref_count_ = 1;
#line 4412 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	_data69_->self = g_ptr_array_ref (self);
#line 4412 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	_tmp0_ = compare_func;
#line 4412 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	_data69_->compare_func = _tmp0_;
#line 4413 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	g_ptr_array_sort_with_data (self, ___lambda1__gcompare_data_func, _data69_);
#line 4412 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	block69_data_unref (_data69_);
#line 4412 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	_data69_ = NULL;
#line 2173 "spice-display.c"
}


static gint ____lambda121_ (SpiceUsbDevice* a, SpiceUsbDevice* b) {
	gint result = 0;
	gchar* str_a = NULL;
	SpiceUsbDevice* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* str_b = NULL;
	SpiceUsbDevice* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	GCompareFunc _tmp4_ = NULL;
	gint _tmp5_ = 0;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (a != NULL, 0);
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (b != NULL, 0);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = a;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = spice_usb_device_get_description (_tmp0_, "    %1$s %2$s");
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	str_a = _tmp1_;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = b;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = spice_usb_device_get_description (_tmp2_, "    %1$s %2$s");
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	str_b = _tmp3_;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = g_strcmp0;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5_ = _tmp4_ (str_a, str_b);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = _tmp5_;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (str_b);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (str_a);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 2215 "spice-display.c"
}


static gint _____lambda121__gcompare_func (gconstpointer a, gconstpointer b) {
	gint result;
	result = ____lambda121_ ((SpiceUsbDevice*) a, (SpiceUsbDevice*) b);
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 2224 "spice-display.c"
}


static Block70Data* block70_data_ref (Block70Data* _data70_) {
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data70_->_ref_count_);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return _data70_;
#line 2233 "spice-display.c"
}


static void block70_data_unref (void * _userdata_) {
	Block70Data* _data70_;
	_data70_ = (Block70Data*) _userdata_;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data70_->_ref_count_)) {
#line 2242 "spice-display.c"
		BoxesSpiceDisplay* self;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self = _data70_->_data68_->self;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data70_->dev_toggle);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		__vala_SpiceUsbDevice_free0 (_data70_->dev);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		block68_data_unref (_data70_->_data68_);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_data70_->_data68_ = NULL;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block70Data, _data70_);
#line 2256 "spice-display.c"
	}
}


static void ___lambda123_ (Block70Data* _data70_, GObject* obj, GAsyncResult* res) {
	Block68Data* _data68_;
	BoxesSpiceDisplay* self;
	GError * _inner_error_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data68_ = _data70_->_data68_;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = _data68_->self;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (res != NULL);
#line 2271 "spice-display.c"
	{
		SpiceUsbDeviceManager* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp0_ = _data68_->manager;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp1_ = res;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		spice_usb_device_manager_connect_device_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2283 "spice-display.c"
			goto __catch76_g_error;
		}
	}
	goto __finally76;
	__catch76_g_error:
	{
		GError* err = NULL;
		GtkSwitch* _tmp2_ = NULL;
		gchar* device_desc = NULL;
		SpiceUsbDevice* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* box_name = NULL;
		gchar* _tmp5_ = NULL;
		gchar* msg = NULL;
		const gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		GError* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		err = _inner_error_;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp2_ = _data70_->dev_toggle;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		gtk_switch_set_active (_tmp2_, FALSE);
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp3_ = _data70_->dev;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp4_ = spice_usb_device_get_description (_tmp3_, "%1$s %2$s");
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		device_desc = _tmp4_;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp5_ = boxes_spice_display_get_box_name (self);
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		box_name = _tmp5_;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = _ ("Redirection of USB device '%s' for '%s' failed");
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp7_ = g_strdup (_tmp6_);
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		msg = _tmp7_;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp8_ = msg;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp9_ = device_desc;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp10_ = box_name;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp11_ = g_strdup_printf (_tmp8_, _tmp9_, _tmp10_);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp12_ = _tmp11_;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_emit_by_name ((BoxesDisplay*) self, "got-error", _tmp12_);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp12_);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp13_ = device_desc;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp14_ = box_name;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp15_ = err;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp16_ = _tmp15_->message;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_debug ("spice-display.vala:349: Error connecting %s to %s: %s", _tmp13_, _tmp14_, _tmp16_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (msg);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (box_name);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (device_desc);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (err);
#line 2365 "spice-display.c"
	}
	__finally76:
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		return;
#line 2376 "spice-display.c"
	}
}


static void ____lambda123__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	___lambda123_ (self, source_object, res);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	block70_data_unref (self);
#line 2386 "spice-display.c"
}


static void _______lambda122_ (Block70Data* _data70_) {
	Block68Data* _data68_;
	BoxesSpiceDisplay* self;
	GtkSwitch* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data68_ = _data70_->_data68_;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = _data68_->self;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data70_->dev_toggle;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = gtk_switch_get_active (_tmp0_);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp2_) {
#line 2408 "spice-display.c"
		SpiceUsbDeviceManager* _tmp3_ = NULL;
		SpiceUsbDevice* _tmp4_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp3_ = _data68_->manager;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp4_ = _data70_->dev;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		spice_usb_device_manager_connect_device_async (_tmp3_, _tmp4_, NULL, ____lambda123__gasync_ready_callback, block70_data_ref (_data70_));
#line 2417 "spice-display.c"
	} else {
		SpiceUsbDeviceManager* _tmp5_ = NULL;
		SpiceUsbDevice* _tmp6_ = NULL;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp5_ = _data68_->manager;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = _data70_->dev;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		spice_usb_device_manager_disconnect_device (_tmp5_, _tmp6_);
#line 2427 "spice-display.c"
	}
}


static void ________lambda122__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_______lambda122_ (self);
#line 2435 "spice-display.c"
}


static void ____lambda124_ (Block68Data* _data68_, SpiceUsbDeviceManager* manager, SpiceUsbDevice* dev) {
	BoxesSpiceDisplay* self;
	BoxesProperty* _tmp0_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = _data68_->self;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (manager != NULL);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (dev != NULL);
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data68_->usb_property;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_signal_emit_by_name (_tmp0_, "refresh-properties");
#line 2452 "spice-display.c"
}


static void _____lambda124__spice_usb_device_manager_device_added (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, gpointer self) {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	____lambda124_ (self, _sender, device);
#line 2459 "spice-display.c"
}


static void ____lambda125_ (Block68Data* _data68_, SpiceUsbDeviceManager* manager, SpiceUsbDevice* dev) {
	BoxesSpiceDisplay* self;
	BoxesProperty* _tmp0_ = NULL;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = _data68_->self;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (manager != NULL);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (dev != NULL);
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data68_->usb_property;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_signal_emit_by_name (_tmp0_, "refresh-properties");
#line 2476 "spice-display.c"
}


static void _____lambda125__spice_usb_device_manager_device_removed (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, gpointer self) {
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	____lambda125_ (self, _sender, device);
#line 2483 "spice-display.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 2490 "spice-display.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_list_free (self);
#line 2499 "spice-display.c"
}


static GList* boxes_spice_display_real_get_properties (BoxesDisplay* base, BoxesPropertiesPage page, PropertyCreationFlag* flags) {
	BoxesSpiceDisplay * self;
	GList* result = NULL;
	GList* list = NULL;
	BoxesPropertiesPage _tmp0_ = 0;
	GError * _inner_error_ = NULL;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	list = NULL;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = page;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	switch (_tmp0_) {
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case BOXES_PROPERTIES_PAGE_GENERAL:
#line 2519 "spice-display.c"
		{
			GtkSwitch* toggle = NULL;
			GtkSwitch* _tmp1_ = NULL;
			SpiceGtkSession* _tmp2_ = NULL;
			GtkSwitch* _tmp3_ = NULL;
			GtkSwitch* _tmp4_ = NULL;
			const gchar* _tmp5_ = NULL;
			GtkSwitch* _tmp6_ = NULL;
			BoxesProperty* _tmp7_ = NULL;
			BoxesProperty* _tmp8_ = NULL;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp1_ = (GtkSwitch*) gtk_switch_new ();
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_object_ref_sink (_tmp1_);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			toggle = _tmp1_;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp2_ = self->priv->gtk_session;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp3_ = toggle;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_object_bind_property_with_closures ((GObject*) _tmp2_, "auto-clipboard", (GObject*) _tmp3_, "active", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp4_ = toggle;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			gtk_widget_set_halign ((GtkWidget*) _tmp4_, GTK_ALIGN_START);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp5_ = _ ("Share Clipboard");
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp6_ = toggle;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp7_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp5_, (GtkWidget*) _tmp6_, NULL);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp8_ = _tmp7_;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (_tmp8_);
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (toggle);
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			break;
#line 2560 "spice-display.c"
		}
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case BOXES_PROPERTIES_PAGE_DEVICES:
#line 2564 "spice-display.c"
		{
			gboolean _tmp9_ = FALSE;
			gboolean _tmp10_ = FALSE;
			PropertyCreationFlag _tmp11_ = 0;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp11_ = *flags;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			if ((_tmp11_ & PROPERTY_CREATION_FLAG_NO_USB) == PROPERTY_CREATION_FLAG_NO_USB) {
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp10_ = TRUE;
#line 2575 "spice-display.c"
			} else {
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp10_ = !HAVE_USBREDIR;
#line 2579 "spice-display.c"
			}
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			if (_tmp10_) {
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp9_ = TRUE;
#line 2585 "spice-display.c"
			} else {
				gboolean _tmp12_ = FALSE;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp12_ = ((BoxesDisplay*) self)->connected;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp9_ = !_tmp12_;
#line 2592 "spice-display.c"
			}
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			if (_tmp9_) {
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				break;
#line 2598 "spice-display.c"
			}
			{
				Block68Data* _data68_;
				SpiceSession* _tmp13_ = NULL;
				SpiceUsbDeviceManager* _tmp14_ = NULL;
				SpiceUsbDeviceManager* _tmp15_ = NULL;
				GPtrArray* devs = NULL;
				SpiceUsbDeviceManager* _tmp16_ = NULL;
				GPtrArray* _tmp17_ = NULL;
				GPtrArray* _tmp18_ = NULL;
				gint _tmp19_ = 0;
				gint _tmp20_ = 0;
				GPtrArray* _tmp21_ = NULL;
				GtkFrame* frame = NULL;
				GtkFrame* _tmp22_ = NULL;
				GtkListBox* listbox = NULL;
				GtkListBox* _tmp23_ = NULL;
				GtkListBox* _tmp24_ = NULL;
				GtkFrame* _tmp25_ = NULL;
				GtkListBox* _tmp26_ = NULL;
				const gchar* _tmp61_ = NULL;
				GtkLabel* _tmp62_ = NULL;
				GtkLabel* _tmp63_ = NULL;
				GtkFrame* _tmp64_ = NULL;
				BoxesProperty* _tmp65_ = NULL;
				BoxesProperty* _tmp66_ = NULL;
				SpiceUsbDeviceManager* _tmp67_ = NULL;
				SpiceUsbDeviceManager* _tmp68_ = NULL;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_data68_ = g_slice_new0 (Block68Data);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_data68_->_ref_count_ = 1;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_data68_->self = g_object_ref (self);
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp13_ = self->priv->session;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp14_ = spice_usb_device_manager_get (_tmp13_, &_inner_error_);
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp15_ = _g_object_ref0 (_tmp14_);
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_data68_->manager = _tmp15_;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					block68_data_unref (_data68_);
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_data68_ = NULL;
#line 2647 "spice-display.c"
					goto __catch75_g_error;
				}
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp16_ = _data68_->manager;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp17_ = boxes_spice_display_get_usb_devices (self, _tmp16_);
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				devs = _tmp17_;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp18_ = devs;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp19_ = g_ptr_array_get_length (_tmp18_);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp20_ = _tmp19_;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				if (_tmp20_ <= 0) {
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					result = list;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_g_ptr_array_unref0 (devs);
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					block68_data_unref (_data68_);
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_data68_ = NULL;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					return result;
#line 2674 "spice-display.c"
				}
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp21_ = devs;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				vala_g_ptr_array_sort (_tmp21_, _____lambda121__gcompare_func);
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp22_ = (GtkFrame*) gtk_frame_new (NULL);
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				g_object_ref_sink (_tmp22_);
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				frame = _tmp22_;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp23_ = (GtkListBox*) gtk_list_box_new ();
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				g_object_ref_sink (_tmp23_);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				listbox = _tmp23_;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp24_ = listbox;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				gtk_widget_set_hexpand ((GtkWidget*) _tmp24_, TRUE);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp25_ = frame;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp26_ = listbox;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				gtk_container_add ((GtkContainer*) _tmp25_, (GtkWidget*) _tmp26_);
#line 2702 "spice-display.c"
				{
					gint i = 0;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					i = 0;
#line 2707 "spice-display.c"
					{
						gboolean _tmp27_ = FALSE;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp27_ = TRUE;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						while (TRUE) {
#line 2714 "spice-display.c"
							Block70Data* _data70_;
							gint _tmp29_ = 0;
							GPtrArray* _tmp30_ = NULL;
							gint _tmp31_ = 0;
							gint _tmp32_ = 0;
							GPtrArray* _tmp33_ = NULL;
							gint _tmp34_ = 0;
							gconstpointer _tmp35_ = NULL;
							SpiceUsbDevice* _tmp36_ = NULL;
							GtkBox* hbox = NULL;
							GtkBox* _tmp37_ = NULL;
							GtkBox* _tmp38_ = NULL;
							GtkBox* _tmp39_ = NULL;
							GtkBox* _tmp40_ = NULL;
							GtkBox* _tmp41_ = NULL;
							GtkLabel* label = NULL;
							SpiceUsbDevice* _tmp42_ = NULL;
							gchar* _tmp43_ = NULL;
							gchar* _tmp44_ = NULL;
							GtkLabel* _tmp45_ = NULL;
							GtkLabel* _tmp46_ = NULL;
							GtkLabel* _tmp47_ = NULL;
							GtkBox* _tmp48_ = NULL;
							GtkLabel* _tmp49_ = NULL;
							GtkSwitch* _tmp50_ = NULL;
							GtkSwitch* _tmp51_ = NULL;
							GtkBox* _tmp52_ = NULL;
							GtkSwitch* _tmp53_ = NULL;
							GtkListBox* _tmp54_ = NULL;
							GtkBox* _tmp55_ = NULL;
							GtkSwitch* _tmp56_ = NULL;
							SpiceUsbDeviceManager* _tmp57_ = NULL;
							SpiceUsbDevice* _tmp58_ = NULL;
							gboolean _tmp59_ = FALSE;
							GtkSwitch* _tmp60_ = NULL;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_data70_ = g_slice_new0 (Block70Data);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_data70_->_ref_count_ = 1;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_data70_->_data68_ = block68_data_ref (_data68_);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							if (!_tmp27_) {
#line 2758 "spice-display.c"
								gint _tmp28_ = 0;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
								_tmp28_ = i;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
								i = _tmp28_ + 1;
#line 2764 "spice-display.c"
							}
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp27_ = FALSE;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp29_ = i;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp30_ = devs;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp31_ = g_ptr_array_get_length (_tmp30_);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp32_ = _tmp31_;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							if (!(_tmp29_ < _tmp32_)) {
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
								block70_data_unref (_data70_);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
								_data70_ = NULL;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
								break;
#line 2784 "spice-display.c"
							}
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp33_ = devs;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp34_ = i;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp35_ = g_ptr_array_index (_tmp33_, (guint) _tmp34_);
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp36_ = __vala_SpiceUsbDevice_copy0 ((SpiceUsbDevice*) _tmp35_);
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_data70_->dev = _tmp36_;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp37_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							g_object_ref_sink (_tmp37_);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							hbox = _tmp37_;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp38_ = hbox;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							gtk_widget_set_margin_start ((GtkWidget*) _tmp38_, 12);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp39_ = hbox;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							gtk_widget_set_margin_end ((GtkWidget*) _tmp39_, 12);
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp40_ = hbox;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							gtk_widget_set_margin_top ((GtkWidget*) _tmp40_, 6);
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp41_ = hbox;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							gtk_widget_set_margin_bottom ((GtkWidget*) _tmp41_, 6);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp42_ = _data70_->dev;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp43_ = spice_usb_device_get_description (_tmp42_, "%1$s %2$s");
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp44_ = _tmp43_;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp45_ = (GtkLabel*) gtk_label_new (_tmp44_);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							g_object_ref_sink (_tmp45_);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp46_ = _tmp45_;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_g_free0 (_tmp44_);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							label = _tmp46_;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp47_ = label;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							gtk_widget_set_halign ((GtkWidget*) _tmp47_, GTK_ALIGN_START);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp48_ = hbox;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp49_ = label;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							gtk_box_pack_start (_tmp48_, (GtkWidget*) _tmp49_, TRUE, TRUE, (guint) 0);
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp50_ = (GtkSwitch*) gtk_switch_new ();
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							g_object_ref_sink (_tmp50_);
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_data70_->dev_toggle = _tmp50_;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp51_ = _data70_->dev_toggle;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							gtk_widget_set_halign ((GtkWidget*) _tmp51_, GTK_ALIGN_END);
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp52_ = hbox;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp53_ = _data70_->dev_toggle;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							gtk_box_pack_start (_tmp52_, (GtkWidget*) _tmp53_, TRUE, TRUE, (guint) 0);
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp54_ = listbox;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp55_ = hbox;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							gtk_list_box_prepend (_tmp54_, (GtkWidget*) _tmp55_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp56_ = _data70_->dev_toggle;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp57_ = _data68_->manager;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp58_ = _data70_->dev;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp59_ = spice_usb_device_manager_is_device_connected (_tmp57_, _tmp58_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							gtk_switch_set_active (_tmp56_, _tmp59_);
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp60_ = _data70_->dev_toggle;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							g_signal_connect_data ((GObject*) _tmp60_, "notify::active", (GCallback) ________lambda122__g_object_notify, block70_data_ref (_data70_), (GClosureNotify) block70_data_unref, 0);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_g_object_unref0 (label);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_g_object_unref0 (hbox);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							block70_data_unref (_data70_);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_data70_ = NULL;
#line 2888 "spice-display.c"
						}
					}
				}
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp61_ = _ ("USB devices");
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp62_ = (GtkLabel*) gtk_label_new ("");
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				g_object_ref_sink (_tmp62_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp63_ = _tmp62_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp64_ = frame;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp65_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp61_, (GtkWidget*) _tmp63_, (GtkWidget*) _tmp64_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp66_ = _tmp65_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_g_object_unref0 (_tmp63_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_data68_->usb_property = _tmp66_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp67_ = _data68_->manager;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				g_signal_connect_data (_tmp67_, "device-added", (GCallback) _____lambda124__spice_usb_device_manager_device_added, block68_data_ref (_data68_), (GClosureNotify) block68_data_unref, 0);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp68_ = _data68_->manager;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				g_signal_connect_data (_tmp68_, "device-removed", (GCallback) _____lambda125__spice_usb_device_manager_device_removed, block68_data_ref (_data68_), (GClosureNotify) block68_data_unref, 0);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_g_object_unref0 (listbox);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_g_object_unref0 (frame);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_g_ptr_array_unref0 (devs);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				block68_data_unref (_data68_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_data68_ = NULL;
#line 2928 "spice-display.c"
			}
			goto __finally75;
			__catch75_g_error:
			{
				GError* _error_ = NULL;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_error_ = _inner_error_;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_inner_error_ = NULL;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_g_error_free0 (_error_);
#line 2940 "spice-display.c"
			}
			__finally75:
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				__g_list_free__g_object_unref0_0 (list);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				g_clear_error (&_inner_error_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				return NULL;
#line 2953 "spice-display.c"
			}
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			break;
#line 2957 "spice-display.c"
		}
		default:
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 2962 "spice-display.c"
	}
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = list;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 2968 "spice-display.c"
}


static void boxes_spice_display_real_send_keys (BoxesDisplay* base, guint* keyvals, int keyvals_length1) {
	BoxesSpiceDisplay * self;
	SpiceDisplay* display = NULL;
	GtkWidget* _tmp0_ = NULL;
	SpiceDisplay* _tmp1_ = NULL;
	guint* _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = boxes_display_get_display ((BoxesDisplay*) self, 0);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp0_) : NULL;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp1_ == NULL) {
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_tmp0_);
#line 2989 "spice-display.c"
	}
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	display = _tmp1_;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = keyvals;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2__length1 = keyvals_length1;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	spice_display_send_keys (display, _tmp2_, _tmp2__length1, SPICE_DISPLAY_KEY_EVENT_CLICK);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (display);
#line 3001 "spice-display.c"
}


static void __vala_SpiceUsbDevice_free0_ (gpointer var) {
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	(var == NULL) ? NULL : (var = (_vala_SpiceUsbDevice_free (var), NULL));
#line 3008 "spice-display.c"
}


static gpointer _libusb_ref_device0 (gpointer self) {
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return self ? libusb_ref_device (self) : NULL;
#line 3015 "spice-display.c"
}


static GPtrArray* boxes_spice_display_get_usb_devices (BoxesSpiceDisplay* self, SpiceUsbDeviceManager* manager) {
	GPtrArray* result = NULL;
	GPtrArray* ret = NULL;
	GPtrArray* _tmp0_ = NULL;
	GPtrArray* devs = NULL;
	SpiceUsbDeviceManager* _tmp1_ = NULL;
	GPtrArray* _tmp2_ = NULL;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (manager != NULL, NULL);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = g_ptr_array_new_full ((guint) 0, __vala_SpiceUsbDevice_free0_);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	ret = _tmp0_;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = manager;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = spice_usb_device_manager_get_devices (_tmp1_);
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	devs = _tmp2_;
#line 3040 "spice-display.c"
	{
		gint i = 0;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		i = 0;
#line 3045 "spice-display.c"
		{
			gboolean _tmp3_ = FALSE;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp3_ = TRUE;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			while (TRUE) {
#line 3052 "spice-display.c"
				gint _tmp5_ = 0;
				GPtrArray* _tmp6_ = NULL;
				gint _tmp7_ = 0;
				gint _tmp8_ = 0;
				SpiceUsbDevice* dev = NULL;
				GPtrArray* _tmp9_ = NULL;
				gint _tmp10_ = 0;
				gconstpointer _tmp11_ = NULL;
				SpiceUsbDevice* _tmp12_ = NULL;
				libusb_device* libusb_dev = NULL;
				SpiceUsbDevice* _tmp13_ = NULL;
				void* _tmp14_ = NULL;
				libusb_device* _tmp15_ = NULL;
				struct libusb_device_descriptor desc = {0};
				libusb_device* _tmp16_ = NULL;
				struct libusb_device_descriptor _tmp17_ = {0};
				gint _tmp18_ = 0;
				struct libusb_device_descriptor _tmp19_ = {0};
				guint8 _tmp20_ = 0U;
				struct libusb_device_descriptor _tmp21_ = {0};
				guint8 _tmp22_ = 0U;
				struct libusb_device_descriptor _tmp23_ = {0};
				guint8 _tmp24_ = 0U;
				gboolean _tmp25_ = FALSE;
				struct libusb_device_descriptor _tmp26_ = {0};
				guint8 _tmp27_ = 0U;
				GPtrArray* _tmp77_ = NULL;
				SpiceUsbDevice* _tmp78_ = NULL;
				SpiceUsbDevice* _tmp79_ = NULL;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				if (!_tmp3_) {
#line 3084 "spice-display.c"
					gint _tmp4_ = 0;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp4_ = i;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					i = _tmp4_ + 1;
#line 3090 "spice-display.c"
				}
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp3_ = FALSE;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp5_ = i;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp6_ = devs;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp7_ = g_ptr_array_get_length (_tmp6_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp8_ = _tmp7_;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				if (!(_tmp5_ < _tmp8_)) {
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					break;
#line 3106 "spice-display.c"
				}
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp9_ = devs;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp10_ = i;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp11_ = g_ptr_array_index (_tmp9_, (guint) _tmp10_);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp12_ = __vala_SpiceUsbDevice_copy0 ((SpiceUsbDevice*) _tmp11_);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				dev = _tmp12_;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp13_ = dev;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp14_ = spice_usb_device_get_libusb_device (_tmp13_);
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp15_ = _libusb_ref_device0 ((libusb_device*) _tmp14_);
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				libusb_dev = _tmp15_;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp16_ = libusb_dev;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp18_ = libusb_get_device_descriptor (_tmp16_, &_tmp17_);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				desc = _tmp17_;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				if (_tmp18_ != 0) {
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_libusb_unref_device0 (libusb_dev);
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					__vala_SpiceUsbDevice_free0 (dev);
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					continue;
#line 3140 "spice-display.c"
				}
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp19_ = desc;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp20_ = _tmp19_.bDeviceClass;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp21_ = desc;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp22_ = _tmp21_.bDeviceSubClass;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp23_ = desc;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp24_ = _tmp23_.bDeviceProtocol;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp25_ = boxes_spice_display_is_usb_kbd_or_mouse (self, _tmp20_, _tmp22_, _tmp24_);
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				if (_tmp25_) {
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_libusb_unref_device0 (libusb_dev);
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					__vala_SpiceUsbDevice_free0 (dev);
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					continue;
#line 3164 "spice-display.c"
				}
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp26_ = desc;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp27_ = _tmp26_.bDeviceClass;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				if (_tmp27_ == LIBUSB_CLASS_PER_INTERFACE) {
#line 3172 "spice-display.c"
					struct libusb_config_descriptor* config = NULL;
					libusb_device* _tmp28_ = NULL;
					struct libusb_config_descriptor* _tmp29_ = NULL;
					gint _tmp30_ = 0;
					gboolean kbd_or_mouse = FALSE;
					gboolean _tmp76_ = FALSE;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp28_ = libusb_dev;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp30_ = libusb_get_active_config_descriptor (_tmp28_, &_tmp29_);
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_libusb_free_config_descriptor0 (config);
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					config = _tmp29_;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					if (_tmp30_ != 0) {
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_libusb_free_config_descriptor0 (config);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_libusb_unref_device0 (libusb_dev);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						__vala_SpiceUsbDevice_free0 (dev);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						continue;
#line 3197 "spice-display.c"
					}
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					kbd_or_mouse = FALSE;
#line 3201 "spice-display.c"
					{
						gint j = 0;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						j = 0;
#line 3206 "spice-display.c"
						{
							gboolean _tmp31_ = FALSE;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_tmp31_ = TRUE;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
							while (TRUE) {
#line 3213 "spice-display.c"
								gboolean _tmp33_ = FALSE;
								gint _tmp34_ = 0;
								struct libusb_config_descriptor* _tmp35_ = NULL;
								struct libusb_interface* _tmp36_ = NULL;
								gint _tmp36__length1 = 0;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
								if (!_tmp31_) {
#line 3221 "spice-display.c"
									gint _tmp32_ = 0;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp32_ = j;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
									j = _tmp32_ + 1;
#line 3227 "spice-display.c"
								}
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
								_tmp31_ = FALSE;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
								_tmp34_ = j;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
								_tmp35_ = config;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
								_tmp36_ = _tmp35_->interface;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
								_tmp36__length1 = _tmp35_->bNumInterfaces;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
								if (_tmp34_ < _tmp36__length1) {
#line 3241 "spice-display.c"
									gboolean _tmp37_ = FALSE;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp37_ = kbd_or_mouse;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp33_ = !_tmp37_;
#line 3247 "spice-display.c"
								} else {
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp33_ = FALSE;
#line 3251 "spice-display.c"
								}
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
								if (!_tmp33_) {
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
									break;
#line 3257 "spice-display.c"
								}
								{
									gint k = 0;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
									k = 0;
#line 3263 "spice-display.c"
									{
										gboolean _tmp38_ = FALSE;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
										_tmp38_ = TRUE;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
										while (TRUE) {
#line 3270 "spice-display.c"
											gboolean _tmp40_ = FALSE;
											gint _tmp41_ = 0;
											struct libusb_config_descriptor* _tmp42_ = NULL;
											struct libusb_interface* _tmp43_ = NULL;
											gint _tmp43__length1 = 0;
											gint _tmp44_ = 0;
											struct libusb_interface _tmp45_ = {0};
											struct libusb_interface_descriptor* _tmp46_ = NULL;
											gint _tmp46__length1 = 0;
											guint8 class = 0U;
											struct libusb_config_descriptor* _tmp48_ = NULL;
											struct libusb_interface* _tmp49_ = NULL;
											gint _tmp49__length1 = 0;
											gint _tmp50_ = 0;
											struct libusb_interface _tmp51_ = {0};
											struct libusb_interface_descriptor* _tmp52_ = NULL;
											gint _tmp52__length1 = 0;
											gint _tmp53_ = 0;
											struct libusb_interface_descriptor _tmp54_ = {0};
											guint8 _tmp55_ = 0U;
											guint8 subclass = 0U;
											struct libusb_config_descriptor* _tmp56_ = NULL;
											struct libusb_interface* _tmp57_ = NULL;
											gint _tmp57__length1 = 0;
											gint _tmp58_ = 0;
											struct libusb_interface _tmp59_ = {0};
											struct libusb_interface_descriptor* _tmp60_ = NULL;
											gint _tmp60__length1 = 0;
											gint _tmp61_ = 0;
											struct libusb_interface_descriptor _tmp62_ = {0};
											guint8 _tmp63_ = 0U;
											guint8 protocol = 0U;
											struct libusb_config_descriptor* _tmp64_ = NULL;
											struct libusb_interface* _tmp65_ = NULL;
											gint _tmp65__length1 = 0;
											gint _tmp66_ = 0;
											struct libusb_interface _tmp67_ = {0};
											struct libusb_interface_descriptor* _tmp68_ = NULL;
											gint _tmp68__length1 = 0;
											gint _tmp69_ = 0;
											struct libusb_interface_descriptor _tmp70_ = {0};
											guint8 _tmp71_ = 0U;
											guint8 _tmp72_ = 0U;
											guint8 _tmp73_ = 0U;
											guint8 _tmp74_ = 0U;
											gboolean _tmp75_ = FALSE;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											if (!_tmp38_) {
#line 3319 "spice-display.c"
												gint _tmp39_ = 0;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
												_tmp39_ = k;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
												k = _tmp39_ + 1;
#line 3325 "spice-display.c"
											}
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp38_ = FALSE;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp41_ = k;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp42_ = config;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp43_ = _tmp42_->interface;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp43__length1 = _tmp42_->bNumInterfaces;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp44_ = j;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp45_ = _tmp43_[_tmp44_];
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp46_ = _tmp45_.altsetting;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp46__length1 = _tmp45_.num_altsetting;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											if (_tmp41_ < _tmp46__length1) {
#line 3347 "spice-display.c"
												gboolean _tmp47_ = FALSE;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
												_tmp47_ = kbd_or_mouse;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
												_tmp40_ = !_tmp47_;
#line 3353 "spice-display.c"
											} else {
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
												_tmp40_ = FALSE;
#line 3357 "spice-display.c"
											}
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											if (!_tmp40_) {
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
												break;
#line 3363 "spice-display.c"
											}
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp48_ = config;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp49_ = _tmp48_->interface;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp49__length1 = _tmp48_->bNumInterfaces;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp50_ = j;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp51_ = _tmp49_[_tmp50_];
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp52_ = _tmp51_.altsetting;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp52__length1 = _tmp51_.num_altsetting;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp53_ = k;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp54_ = _tmp52_[_tmp53_];
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp55_ = _tmp54_.bInterfaceClass;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											class = _tmp55_;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp56_ = config;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp57_ = _tmp56_->interface;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp57__length1 = _tmp56_->bNumInterfaces;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp58_ = j;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp59_ = _tmp57_[_tmp58_];
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp60_ = _tmp59_.altsetting;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp60__length1 = _tmp59_.num_altsetting;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp61_ = k;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp62_ = _tmp60_[_tmp61_];
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp63_ = _tmp62_.bInterfaceSubClass;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											subclass = _tmp63_;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp64_ = config;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp65_ = _tmp64_->interface;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp65__length1 = _tmp64_->bNumInterfaces;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp66_ = j;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp67_ = _tmp65_[_tmp66_];
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp68_ = _tmp67_.altsetting;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp68__length1 = _tmp67_.num_altsetting;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp69_ = k;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp70_ = _tmp68_[_tmp69_];
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp71_ = _tmp70_.bInterfaceProtocol;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											protocol = _tmp71_;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp72_ = class;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp73_ = subclass;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp74_ = protocol;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											_tmp75_ = boxes_spice_display_is_usb_kbd_or_mouse (self, _tmp72_, _tmp73_, _tmp74_);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
											kbd_or_mouse = _tmp75_;
#line 3441 "spice-display.c"
										}
									}
								}
							}
						}
					}
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp76_ = kbd_or_mouse;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					if (_tmp76_) {
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_libusb_free_config_descriptor0 (config);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_libusb_unref_device0 (libusb_dev);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						__vala_SpiceUsbDevice_free0 (dev);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						continue;
#line 3460 "spice-display.c"
					}
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_libusb_free_config_descriptor0 (config);
#line 3464 "spice-display.c"
				}
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp77_ = ret;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp78_ = dev;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp79_ = __vala_SpiceUsbDevice_copy0 (_tmp78_);
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				g_ptr_array_add (_tmp77_, _tmp79_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_libusb_unref_device0 (libusb_dev);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				__vala_SpiceUsbDevice_free0 (dev);
#line 3478 "spice-display.c"
			}
		}
	}
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = ret;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_ptr_array_unref0 (devs);
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 3488 "spice-display.c"
}


static gboolean boxes_spice_display_is_usb_kbd_or_mouse (BoxesSpiceDisplay* self, guint8 class, guint8 subclass, guint8 protocol) {
	gboolean result = FALSE;
	gboolean ret = FALSE;
	guint8 _tmp0_ = 0U;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	ret = FALSE;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = class;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp0_ == LIBUSB_CLASS_HID) {
#line 3504 "spice-display.c"
		guint8 _tmp1_ = 0U;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp1_ = subclass;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		switch (_tmp1_) {
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			case 0x00:
#line 3512 "spice-display.c"
			{
#line 432 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				break;
#line 3516 "spice-display.c"
			}
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			case 0x01:
#line 3520 "spice-display.c"
			{
				guint8 _tmp2_ = 0U;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp2_ = protocol;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				switch (_tmp2_) {
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					case 0x00:
#line 3529 "spice-display.c"
					{
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						break;
#line 3533 "spice-display.c"
					}
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					case 0x01:
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					case 0x02:
#line 3539 "spice-display.c"
					{
#line 439 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						ret = TRUE;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						break;
#line 3545 "spice-display.c"
					}
					default:
					{
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
						break;
#line 3551 "spice-display.c"
					}
				}
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				break;
#line 3556 "spice-display.c"
			}
			default:
			{
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				break;
#line 3562 "spice-display.c"
			}
		}
	}
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = ret;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 3570 "spice-display.c"
}


static const gchar* boxes_spice_display_real_get_protocol (BoxesDisplay* base) {
	const gchar* result;
	BoxesSpiceDisplay* self;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = "SPICE";
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 3583 "spice-display.c"
}


static gchar* boxes_spice_display_real_get_uri (BoxesDisplay* base) {
	gchar* result;
	BoxesSpiceDisplay* self;
	SpiceSession* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp0_, "uri", &_tmp1_, NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = _tmp2_;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 3605 "spice-display.c"
}


GByteArray* boxes_spice_display_get_ca_cert (BoxesSpiceDisplay* self) {
	GByteArray* result;
	SpiceSession* _tmp0_ = NULL;
	GByteArray* _tmp1_ = NULL;
	GByteArray* _tmp2_ = NULL;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp0_, "ca", &_tmp1_, NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = _tmp2_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 3626 "spice-display.c"
}


void boxes_spice_display_set_ca_cert (BoxesSpiceDisplay* self, GByteArray* value) {
	SpiceSession* _tmp0_ = NULL;
	GByteArray* _tmp1_ = NULL;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = value;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp0_, "ca", _tmp1_, NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_notify ((GObject *) self, "ca-cert");
#line 3643 "spice-display.c"
}


static void _boxes_spice_display____lambda126_ (BoxesSpiceDisplay* self, SpiceUsbDevice* dev, GError* err) {
	gchar* device_description = NULL;
	SpiceUsbDevice* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* box_name = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	GError* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (dev != NULL);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = dev;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = spice_usb_device_get_description (_tmp0_, "%1$s %2$s");
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	device_description = _tmp1_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = boxes_spice_display_get_box_name (self);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	box_name = _tmp2_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _ ("Redirection of USB device '%s' for '%s' failed");
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = device_description;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5_ = box_name;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp6_ = g_strdup_printf (_tmp3_, _tmp4_, _tmp5_);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp7_ = _tmp6_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_signal_emit_by_name ((BoxesDisplay*) self, "got-error", _tmp7_);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp7_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp8_ = device_description;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp9_ = box_name;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp10_ = err;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp11_ = _tmp10_->message;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_debug ("spice-display.vala:52: Error connecting %s to %s: %s", _tmp8_, _tmp9_, _tmp11_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (box_name);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (device_description);
#line 3702 "spice-display.c"
}


static void __boxes_spice_display____lambda126__spice_usb_device_manager_device_error (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, GError* _error_, gpointer self) {
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_boxes_spice_display____lambda126_ ((BoxesSpiceDisplay*) self, device, _error_);
#line 3709 "spice-display.c"
}


static void _boxes_spice_display___lambda127_ (BoxesSpiceDisplay* self) {
	BoxesBoxConfig* _tmp0_ = NULL;
	BoxesBoxConfig* _tmp1_ = NULL;
	SpiceGtkSession* _tmp2_ = NULL;
	BoxesBoxConfigSyncProperty* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = boxes_display_get_config ((BoxesDisplay*) self);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _tmp0_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = self->priv->gtk_session;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = self->priv->gtk_session_sync_properties;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3__length1 = self->priv->gtk_session_sync_properties_length1;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_box_config_sync_properties (_tmp1_, (GObject*) _tmp2_, _tmp3_, _tmp3__length1);
#line 3731 "spice-display.c"
}


static void __boxes_spice_display___lambda127__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_boxes_spice_display___lambda127_ ((BoxesSpiceDisplay*) self);
#line 3738 "spice-display.c"
}


static GObject * boxes_spice_display_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesSpiceDisplay * self;
	gchar* _tmp0_ = NULL;
	GValue _tmp1_ = {0};
	BoxesBoxConfigSyncProperty _tmp2_ = {0};
	BoxesBoxConfigSyncProperty* _tmp3_ = NULL;
	SpiceSession* _tmp4_ = NULL;
	SpiceSession* _tmp5_ = NULL;
	SpiceAudio* _tmp6_ = NULL;
	SpiceSession* _tmp7_ = NULL;
	SpiceGtkSession* _tmp8_ = NULL;
	GError * _inner_error_ = NULL;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	parent_class = G_OBJECT_CLASS (boxes_spice_display_parent_class);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = g_strdup ("auto-clipboard");
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_value_init (&_tmp1_, G_TYPE_BOOLEAN);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_value_set_boolean (&_tmp1_, TRUE);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	memset (&_tmp2_, 0, sizeof (BoxesBoxConfigSyncProperty));
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp2_.name);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_.name = _tmp0_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	G_IS_VALUE (&_tmp2_.default_value) ? (g_value_unset (&_tmp2_.default_value), NULL) : NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_.default_value = _tmp1_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = g_new0 (BoxesBoxConfigSyncProperty, 1);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_[0] = _tmp2_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_sync_properties = (_vala_BoxesBoxConfigSyncProperty_array_free (self->priv->gtk_session_sync_properties, self->priv->gtk_session_sync_properties_length1), NULL);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_sync_properties = _tmp3_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_sync_properties_length1 = 1;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->_gtk_session_sync_properties_size_ = self->priv->gtk_session_sync_properties_length1;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_display_set_need_password ((BoxesDisplay*) self, FALSE);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = spice_session_new ();
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->session);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->session = _tmp4_;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5_ = self->priv->session;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp6_ = spice_audio_get (_tmp5_, NULL);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->audio = _tmp6_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp7_ = self->priv->session;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp8_ = spice_gtk_session_get (_tmp7_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session = _tmp8_;
#line 3810 "spice-display.c"
	{
		SpiceUsbDeviceManager* manager = NULL;
		SpiceSession* _tmp9_ = NULL;
		SpiceUsbDeviceManager* _tmp10_ = NULL;
		SpiceUsbDeviceManager* _tmp11_ = NULL;
		SpiceUsbDeviceManager* _tmp12_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp9_ = self->priv->session;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp10_ = spice_usb_device_manager_get (_tmp9_, &_inner_error_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp11_ = _g_object_ref0 (_tmp10_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		manager = _tmp11_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3827 "spice-display.c"
			goto __catch77_g_error;
		}
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp12_ = manager;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_connect_object (_tmp12_, "device-error", (GCallback) __boxes_spice_display____lambda126__spice_usb_device_manager_device_error, self, 0);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (manager);
#line 3836 "spice-display.c"
	}
	goto __finally77;
	__catch77_g_error:
	{
		GError* _error_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_error_ = _inner_error_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (_error_);
#line 3848 "spice-display.c"
	}
	__finally77:
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 3857 "spice-display.c"
	}
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_signal_connect_object ((GObject*) self, "notify::config", (GCallback) __boxes_spice_display___lambda127__g_object_notify, self, 0);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return obj;
#line 3863 "spice-display.c"
}


static void boxes_spice_display_class_init (BoxesSpiceDisplayClass * klass) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_parent_class = g_type_class_peek_parent (klass);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_type_class_add_private (klass, sizeof (BoxesSpiceDisplayPrivate));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->get_display = boxes_spice_display_real_get_display;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->should_keep_alive = boxes_spice_display_real_should_keep_alive;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->set_enable_audio = boxes_spice_display_real_set_enable_audio;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->set_enable_inputs = boxes_spice_display_real_set_enable_inputs;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->get_pixbuf = boxes_spice_display_real_get_pixbuf;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->collect_logs = boxes_spice_display_real_collect_logs;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->connect_it = boxes_spice_display_real_connect_it;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->disconnect_it = boxes_spice_display_real_disconnect_it;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->get_properties = boxes_spice_display_real_get_properties;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	((BoxesDisplayClass *) klass)->send_keys = boxes_spice_display_real_send_keys;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_protocol = boxes_spice_display_real_get_protocol;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_uri = boxes_spice_display_real_get_uri;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_spice_display_get_property;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_spice_display_set_property;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_spice_display_constructor;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_spice_display_finalize;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SPICE_DISPLAY_PROTOCOL, g_param_spec_string ("protocol", "protocol", "protocol", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SPICE_DISPLAY_URI, g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SPICE_DISPLAY_CA_CERT, g_param_spec_boxed ("ca-cert", "ca-cert", "ca-cert", G_TYPE_BYTE_ARRAY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3910 "spice-display.c"
}


static void boxes_spice_display_instance_init (BoxesSpiceDisplay * self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv = BOXES_SPICE_DISPLAY_GET_PRIVATE (self);
#line 3917 "spice-display.c"
}


static void boxes_spice_display_finalize (GObject* obj) {
	BoxesSpiceDisplay * self;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_main_cleanup (self);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->session);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->display_sync_properties = (_vala_BoxesBoxConfigSyncProperty_array_free (self->priv->display_sync_properties, self->priv->display_sync_properties_length1), NULL);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_sync_properties = (_vala_BoxesBoxConfigSyncProperty_array_free (self->priv->gtk_session_sync_properties, self->priv->gtk_session_sync_properties_length1), NULL);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->main_channel);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (boxes_spice_display_parent_class)->finalize (obj);
#line 3937 "spice-display.c"
}


GType boxes_spice_display_get_type (void) {
	static volatile gsize boxes_spice_display_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_spice_display_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSpiceDisplayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_spice_display_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSpiceDisplay), 0, (GInstanceInitFunc) boxes_spice_display_instance_init, NULL };
		GType boxes_spice_display_type_id;
		boxes_spice_display_type_id = g_type_register_static (BOXES_TYPE_DISPLAY, "BoxesSpiceDisplay", &g_define_type_info, 0);
		g_once_init_leave (&boxes_spice_display_type_id__volatile, boxes_spice_display_type_id);
	}
	return boxes_spice_display_type_id__volatile;
}


static void _vala_boxes_spice_display_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesSpiceDisplay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	switch (property_id) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_PROTOCOL:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_value_set_string (value, boxes_display_get_protocol ((BoxesDisplay*) self));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_URI:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_value_take_string (value, boxes_display_get_uri ((BoxesDisplay*) self));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_CA_CERT:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_value_take_boxed (value, boxes_spice_display_get_ca_cert (self));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 3976 "spice-display.c"
		default:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 3982 "spice-display.c"
	}
}


static void _vala_boxes_spice_display_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSpiceDisplay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	switch (property_id) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_CA_CERT:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		boxes_spice_display_set_ca_cert (self, g_value_get_boxed (value));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 3998 "spice-display.c"
		default:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 4004 "spice-display.c"
	}
}


static gint* _int_dup (gint* self) {
	gint* dup;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	dup = g_new0 (gint, 1);
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	memcpy (dup, self, sizeof (gint));
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return dup;
#line 4017 "spice-display.c"
}


static gpointer __int_dup0 (gpointer self) {
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return self ? _int_dup (self) : NULL;
#line 4024 "spice-display.c"
}


void spice_validate_uri (const gchar* uri_as_text, gint** port, gint** tls_port, GError** error) {
	gint* _vala_port = NULL;
	gint* _vala_tls_port = NULL;
	xmlURI* uri = NULL;
	const gchar* _tmp0_ = NULL;
	xmlURI* _tmp1_ = NULL;
	xmlURI* _tmp2_ = NULL;
	gint _tmp5_ = 0;
	gint* _tmp6_ = NULL;
	xmlURI* _tmp7_ = NULL;
	gint _tmp8_ = 0;
	gint* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	xmlURI* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	gchar* query_str = NULL;
	gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	gboolean _tmp40_ = FALSE;
	gint* _tmp41_ = NULL;
	GError * _inner_error_ = NULL;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (uri_as_text != NULL);
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = uri_as_text;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = xmlParseURI (_tmp0_);
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	uri = _tmp1_;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = uri;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp2_ == NULL) {
#line 4061 "spice-display.c"
		const gchar* _tmp3_ = NULL;
		GError* _tmp4_ = NULL;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp3_ = _ ("Invalid URI");
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp4_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp3_);
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_inner_error_ = _tmp4_;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_propagate_error (error, _inner_error_);
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_xmlFreeURI0 (uri);
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			return;
#line 4078 "spice-display.c"
		} else {
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_xmlFreeURI0 (uri);
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_clear_error (&_inner_error_);
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			return;
#line 4088 "spice-display.c"
		}
	}
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5_ = 0;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp6_ = __int_dup0 (&_tmp5_);
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (_vala_tls_port);
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_vala_tls_port = _tmp6_;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp7_ = uri;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp8_ = _tmp7_->port;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp9_ = __int_dup0 (&_tmp8_);
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (_vala_port);
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_vala_port = _tmp9_;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp11_ = uri;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp12_ = _tmp11_->query_raw;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp10_ = _tmp12_;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp10_ == NULL) {
#line 4117 "spice-display.c"
		xmlURI* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp13_ = uri;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp14_ = _tmp13_->query;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp10_ = _tmp14_;
#line 4126 "spice-display.c"
	}
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp15_ = g_strdup (_tmp10_);
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	query_str = _tmp15_;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp16_ = query_str;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp16_ != NULL) {
#line 4136 "spice-display.c"
		BoxesQuery* query = NULL;
		const gchar* _tmp17_ = NULL;
		BoxesQuery* _tmp18_ = NULL;
		BoxesQuery* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gboolean _tmp22_ = FALSE;
		BoxesQuery* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gboolean _tmp34_ = FALSE;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp17_ = query_str;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp18_ = boxes_query_new (_tmp17_);
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		query = _tmp18_;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp19_ = query;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp20_ = boxes_query_get (_tmp19_, "port");
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp21_ = _tmp20_;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp22_ = _tmp21_ != NULL;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp21_);
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp22_) {
#line 4166 "spice-display.c"
			gint* _tmp23_ = NULL;
			BoxesQuery* _tmp26_ = NULL;
			gchar* _tmp27_ = NULL;
			gchar* _tmp28_ = NULL;
			gint _tmp29_ = 0;
			gint* _tmp30_ = NULL;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp23_ = _vala_port;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			if ((*_tmp23_) > 0) {
#line 4177 "spice-display.c"
				const gchar* _tmp24_ = NULL;
				GError* _tmp25_ = NULL;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp24_ = _ ("The port must be specified once");
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp25_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp24_);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_inner_error_ = _tmp25_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
				if (_inner_error_->domain == BOXES_ERROR) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					g_propagate_error (error, _inner_error_);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_g_object_unref0 (query);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_g_free0 (query_str);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_xmlFreeURI0 (uri);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					return;
#line 4198 "spice-display.c"
				} else {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_g_object_unref0 (query);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_g_free0 (query_str);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_xmlFreeURI0 (uri);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					g_clear_error (&_inner_error_);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
					return;
#line 4212 "spice-display.c"
				}
			}
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp26_ = query;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp27_ = boxes_query_get (_tmp26_, "port");
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp28_ = _tmp27_;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp29_ = atoi (_tmp28_);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp30_ = __int_dup0 (&_tmp29_);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_free0 (_vala_port);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_vala_port = _tmp30_;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_free0 (_tmp28_);
#line 4231 "spice-display.c"
		}
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp31_ = query;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp32_ = boxes_query_get (_tmp31_, "tls-port");
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp33_ = _tmp32_;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp34_ = _tmp33_ != NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp33_);
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp34_) {
#line 4245 "spice-display.c"
			BoxesQuery* _tmp35_ = NULL;
			gchar* _tmp36_ = NULL;
			gchar* _tmp37_ = NULL;
			gint _tmp38_ = 0;
			gint* _tmp39_ = NULL;
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp35_ = query;
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp36_ = boxes_query_get (_tmp35_, "tls-port");
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp37_ = _tmp36_;
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp38_ = atoi (_tmp37_);
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp39_ = __int_dup0 (&_tmp38_);
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_free0 (_vala_tls_port);
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_vala_tls_port = _tmp39_;
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_free0 (_tmp37_);
#line 4267 "spice-display.c"
		}
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (query);
#line 4271 "spice-display.c"
	}
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp41_ = _vala_port;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if ((*_tmp41_) <= 0) {
#line 4277 "spice-display.c"
		gint* _tmp42_ = NULL;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp42_ = _vala_tls_port;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp40_ = (*_tmp42_) <= 0;
#line 4283 "spice-display.c"
	} else {
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp40_ = FALSE;
#line 4287 "spice-display.c"
	}
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp40_) {
#line 4291 "spice-display.c"
		const gchar* _tmp43_ = NULL;
		GError* _tmp44_ = NULL;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp43_ = _ ("Missing port in Spice URI");
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp44_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp43_);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_inner_error_ = _tmp44_;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_propagate_error (error, _inner_error_);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_free0 (query_str);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_xmlFreeURI0 (uri);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			return;
#line 4310 "spice-display.c"
		} else {
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_free0 (query_str);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_xmlFreeURI0 (uri);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_clear_error (&_inner_error_);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
			return;
#line 4322 "spice-display.c"
		}
	}
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (query_str);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_xmlFreeURI0 (uri);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (port) {
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		*port = _vala_port;
#line 4333 "spice-display.c"
	} else {
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_vala_port);
#line 4337 "spice-display.c"
	}
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (tls_port) {
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		*tls_port = _vala_tls_port;
#line 4343 "spice-display.c"
	} else {
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_vala_tls_port);
#line 4347 "spice-display.c"
	}
}



